@@ -40,6 +40,7 @@
 
 
 ;;;;;;;;;;;;;;;;; ExtraOffset
+;;; the parameter "what" is the LilyPond grob that is being tweaked - it may not be the tag of the DenemoDirective that is being edited
 (define* (ExtraOffset what  #:optional (type "chord") (context ""))
   (let ((tag "")(oldstr #f) (start "") (end "") (get-command d-DirectiveGet-chord-prefix)  (put-command d-DirectivePut-chord-prefix))
     (cond
@@ -550,7 +551,7 @@
 |Name = " name "
 |Author =  " (scheme-escape(d-GetUserName)) "  
 |Label = " label  "
-|License = " GPL "
+|License =  GPL 
 |Explanation = " tooltip "
 |SubLabel = " menupath "
 |Version = " DENEMO_VERSION "
@@ -581,7 +582,7 @@
 			)	
 			
 			;Show script in browser
-			(d-Help (string-append "http://" hostname "/index.php/" name))				
+			(d-Help (string-append "http://" HTTPHostname "/index.php/" name))				
 	
 		); End of GetLicenseAndBuildString
 	
@@ -601,3 +602,7 @@
 
 ) ; End Of (d-UploadRoutine)
 
+(define (PlayNote pitch duration)
+  (d-OutputMIDI (string-append "0x9$ " pitch " %%%"))
+ (d-OneShotTimer duration (string-append "(d-OutputMIDI " "\"" "0x8$ " pitch " %%%" "\"" ")" )) 
+  )
