@@ -23,6 +23,8 @@
 
 #define DENEMO_DEFAULT_ANON_FTP "ftp://www.denemo.org/download/"
 
+#define DENEMO_TEXTEDITOR_TAG "texteditor"
+
 typedef void (*GActionCallback) (GtkAction *action, gpointer data);
 #define G_ACTIONCALLBACK(f) ((GActionCallback)(f)) 
  /* and the following typedefs are basically here for so that it's
@@ -359,7 +361,8 @@ typedef struct DenemoDirective
   gint tx,ty; /**< x and y offsets in pixels for the display text */
   gint minpixels;/**< horizontal space needed by the display */
   gint x, y; /**< x and y offsets passed to LilyPond to control printed position */
-  gpointer graphic; /**< bitmap to draw for this directive, or for directives that cannot be drawn a widget to display for it */
+  GObject *graphic; /**< bitmap to draw for this directive */
+  GtkWidget *widget;  /**<  a button or menu item for accessing the directive for editing or actioning */
   gint gx, gy; /**< x and y offsets in pixels for the graphic */
   GString *graphic_name; /**< name of the graphic to be drawn */
   gint width, height; /**< width and height of the bitmap */
@@ -367,6 +370,7 @@ typedef struct DenemoDirective
 #define DENEMO_OVERRIDE_LILYPOND (1<<0)
 #define DENEMO_OVERRIDE_UNUSED (1<<1)
 #define DENEMO_OVERRIDE_GRAPHIC (1<<2)
+#define DENEMO_OVERRIDE_EDITOR (1<<3)
 
 
 
@@ -655,7 +659,6 @@ typedef struct DenemoScore
 
   
   GList *savebuffer;
-  /* Holds List of Plugin Names */
   
 
 
@@ -706,8 +709,6 @@ typedef struct DenemoGUI
   gchar *namespec;/**< A spec of which parts/movements to print */
   
 
-  GList *plugins;
-  gint plugincounter;
 
   GtkWidget* articulation_palette; /**< Articulation palette window */
   InputSource input_source;/**< Where pitches are coming into Denemo (keyboard, audio, midi) */
