@@ -96,9 +96,21 @@ void nextrhythm(DenemoGUI *gui) {
  * isstart/end_beamgroup, is_stemup, stemy, is_reversealigned. reversealign, minpixelsalloted, space_before
  * si->curmeasureclef is also set: it is set to the value prevailing at the end of the measure.
  */
+
 void
 beamandstemdirhelper (DenemoScore * si)
 {
+  DenemoObject *theclef=NULL;
+  if(si->currentmeasure->prev){
+    objnode *curobj = lastobjnode(si->currentmeasure->prev);
+    if(curobj)
+      theclef = get_clef_before_object(curobj);
+  }
+  if(theclef)
+    si->curmeasureclef = ((clef*)theclef->object)->type;
+  else
+    si->curmeasureclef =  ((DenemoStaff*)si->currentstaff->data)->clef.type;
+
   calculatebeamsandstemdirs
     ((objnode *) si->currentmeasure->data, &(si->curmeasureclef),
      &(si->cursortime1), &(si->cursortime2),
@@ -223,6 +235,23 @@ jumpcursor (gint cursor_y, gint fromnote, gint tonote)
     return cursor_y - 7 + distance;
 }
 
+/**
+ * Reset the cursor stats: sets currentobject to the si->cursor_x'th object in currentmeasure, if no such object sets cursor_appending. NOTE does not set cursor appending false if there is an object... 
+ * @param si pointer to the scoreinfo structure
+ * @return none
+ */
+static void
+reset_cursor_stats (DenemoScore * si)
+{
+  si->currentobject = g_list_nth ((objnode *) si->currentmeasure->data,
+				  si->cursor_x);
+  if (!si->currentobject)
+    {
+      si->currentobject = g_list_last ((objnode *) si->currentmeasure->data);
+      si->cursor_appending = TRUE;
+    }
+}
+
 /**
  *  General function for inserting a DenemoObject
  *  into the score
@@ -250,6 +279,27 @@ object_insert (DenemoGUI * gui, DenemoObject * mudela_obj_new)
   si->currentmeasure->data =
     g_list_insert ((objnode *) si->currentmeasure->data,
 		   mudela_obj_new, si->cursor_x);
+#if 0
+  if(mudela_obj_new->type == CHORD) {
+    chord *newchord = (chord *) mudela_obj_new->object;
+there is a function newclefify and fixnoteheights...
+    if(newchord->notes){
+      gint dclef = find_prevailing_clef(si);
+      newchord->lowesty = calculateheight (newchord->lowestpitch, dclef);
+      newchord->highesty = calculateheight (newchord->highestpitch, dclef);
+      newchord->stemy = calculateheight (stemoffset, dclef);
+ beamsandstemdirswholestaff is the only thing I think???
+    }
+  }
+#endif
+
+
+  if(mudela_obj_new->type == CLEF) {
+	  reset_cursor_stats (si);
+	  fixnoteheights ((DenemoStaff *) si->currentstaff->data);
+	  beamsandstemdirswholestaff ((DenemoStaff *) si->currentstaff->data);
+	  find_xes_in_all_measures (si);
+  }
 
   /* update undo information */
   undo->position = si->cursor_x;
@@ -298,7 +348,11 @@ measureleft (DenemoScriptParam *param)
     param = &dummy;
   param->status = FALSE;
 
-  if (!gui->si->cursor_x && gui->si->currentmeasure->prev)
+  if (
+#if 0 //this prevents deletion going past empty measures
+!gui->si->cursor_x && 
+#endif
+gui->si->currentmeasure->prev)
     {
       gui->si->currentmeasurenum--;
       isoffleftside (gui);
@@ -482,7 +536,7 @@ voiceup (DenemoScriptParam *param)
     return param->status = TRUE;
     } else
       if(param==&dummy)//is interactive
-	warningdialog("This is the first voice");
+	warningmessage("This is the first voice");
   return param->status = FALSE;
 }
 
@@ -512,12 +566,12 @@ staffup (DenemoScriptParam *param)
       setcurrents (gui->si);
       show_lyrics();
       find_leftmost_allcontexts (si);
-      gtk_widget_draw (gui->scorearea, NULL);//KLUDGE FIXME gets cursorclef set
+      gtk_widget_draw (gui->scorearea, NULL);//KLUDGE FIXME gets cursorclef set I think it just needs si->cursorclef = si->curmeasureclef (? after beamandstemdirhelper(si)??)
       move_viewport_up (gui);
       return param->status = TRUE;
     } else
       if(param==&dummy)//is interactive
-	warningdialog("This is the first staff");
+	warningmessage("This is the first staff");
   return param->status = FALSE;
 }
 
@@ -548,7 +602,7 @@ voicedown (DenemoScriptParam *param)
       return param->status = TRUE;
     } else
       if(param==&dummy)//is interactive
-      warningdialog("This is the last voice");
+      warningmessage("This is the last voice");
   return param->status = FALSE;
 }
 /**
@@ -583,7 +637,7 @@ staffdown (DenemoScriptParam *param)
       return param->status = TRUE;
     } else
       if(param==&dummy)//is interactive
-      warningdialog("This is the last staff");
+      warningmessage("This is the last staff");
   return param->status = FALSE;
 }
 
@@ -1426,23 +1480,6 @@ remove_object (measurenode * cur_measure, objnode * cur_objnode)
 }
 
 
-/**
- * Reset the cursor stats 
- * @param si pointer to the scoreinfo structure
- * @return none
- */
-static void
-reset_cursor_stats (DenemoScore * si)
-{
-  si->currentobject = g_list_nth ((objnode *) si->currentmeasure->data,
-				  si->cursor_x);
-  if (!si->currentobject)
-    {
-      si->currentobject = g_list_last ((objnode *) si->currentmeasure->data);
-      si->cursor_appending = TRUE;
-    }
-}
-
 /**
  * Helper to remove the current object an reset cursor stats
  * @param si pointer to the scoreinfo structure
