@@ -117,6 +117,7 @@ struct infotopass
   gint in_highy; // FIXME these are passed in so that highy, lowy do not need to be passed back
   gint in_lowy;
   gboolean mark;//whether the region is selected
+  gboolean *wronglengths;// array of indicators for each measure drawn whether it is correct length 
 };
 
 /* count the number of syllables up to staff->leftmeasurenum */
@@ -124,7 +125,7 @@ static gint count_syllables(DenemoStaff *staff, gint from) {
   gint count = 0;
   gint i;
   GList *curmeasure = staff->measures;
-  for(i=1;i<from;i++, curmeasure = curmeasure->next) {
+  for(i=1;curmeasure && (i<from);i++, curmeasure = curmeasure->next) {
     objnode *curobj;
     for(curobj = curmeasure->data;curobj;curobj=curobj->next) {
       DenemoObject *obj = curobj->data;
@@ -137,6 +138,8 @@ static gint count_syllables(DenemoStaff *staff, gint from) {
 	    in_slur = TRUE;
 	  if (thechord->slur_end_p)
 	    in_slur = FALSE;
+	  if (thechord->is_tied)
+	    count--;
       }
     }
   }
@@ -251,7 +254,10 @@ draw_object (objnode * curobj, gint x, gint y,
 		      itp->curaccs, itp->mark);
 	}
 
-       if (si->currentstaffnum==itp->staffnum && itp->verse && thechord->notes   && !itp->slur_stack )
+       if (si->currentstaffnum==itp->staffnum 
+	   && itp->verse && thechord->notes   
+	   && !itp->slur_stack
+	   && !thechord->is_tied)
 	{
 	  gchar *syllable = (gchar *) next_syllable();
 	  if(syllable)
@@ -455,8 +461,9 @@ draw_object (objnode * curobj, gint x, gint y,
  * @param y
  * @param gui
  * @param itp
+ * return TRUE if measure has correct number of beats
  */
-void
+static gboolean
 draw_measure (measurenode * curmeasure, gint x, gint y,
 	      DenemoGUI * gui, struct infotopass *itp)
 {
@@ -498,10 +505,10 @@ draw_measure (measurenode * curmeasure, gint x, gint y,
       si->cursortime2 = itp->time2;
     }
 
-  /* If this is the current staff, paint the measure number at the
+  /*  paint the measure number at the
    * preceding barline */
 
-  if (si->currentstaffnum == itp->staffnum)
+  //  if (si->currentstaffnum == itp->staffnum)
     {
       g_string_sprintf (mstring, "%d", itp->measurenum);
       pango_layout_set_text (layout, mstring->str, -1);
@@ -513,13 +520,14 @@ draw_measure (measurenode * curmeasure, gint x, gint y,
 
       //gdk_draw_text (si->pixmap, mnumfont, itp->gc, x - SPACE_FOR_BARLINE,
       // y - 2, mstring->str, mstring->len);
-      if (si->currentmeasurenum == itp->measurenum && !si->currentobject)
+      if (si->currentmeasurenum == itp->measurenum && !si->currentobject && (si->currentstaffnum == itp->staffnum))
 	{
 	  /* That is, the cursor's at the beginning of this blank measure */
-	  si->cursoroffend = FALSE;
+	  si->cursoroffend = FALSE; 
 	  draw_cursor (gui->pixmap, si, x, y, gui->mode, itp->clef->type);
 	  memcpy (si->cursoraccs, itp->curaccs, SEVENGINTS);
 	  si->cursorclef = itp->clef->type;
+	  
 	}
     }
   curobj = (objnode *) curmeasure->data;
@@ -578,6 +586,7 @@ draw_measure (measurenode * curmeasure, gint x, gint y,
     drawbitmapinverse (gui->pixmap, exclamgc, exclam,
 		       x, y - 8 - EXCL_HEIGHT,
 		       EXCL_WIDTH, EXCL_HEIGHT);
+  return exclamgc!=NULL;
 }
 
 /**
@@ -665,7 +674,7 @@ draw_staff (DenemoStaff * curstaffstruct, gint y,
     {
       if(itp->measurenum == si->rightmeasurenum+1)
 	itp->gc = slategraygc;
-      draw_measure (itp->curmeasure, x, y, gui, itp);
+      itp->wronglengths[itp->measurenum-si->leftmeasurenum] = draw_measure (itp->curmeasure, x, y, gui, itp);
       x += GPOINTER_TO_INT (itp->mwidthiterator->data) + SPACE_FOR_BARLINE;
       itp->curmeasure = itp->curmeasure->next;
       itp->mwidthiterator = itp->mwidthiterator->next;
@@ -738,7 +747,7 @@ draw_score (GtkWidget * widget, DenemoGUI * gui)
     itp.in_highy = highy, itp.in_lowy = lowy;
     itp.highy = 0;//do not pass on extra_space from one staff to the next
 	gdk_draw_rectangle (gui->pixmap, gcs_lightbluegc(), TRUE, 0, y, LEFT_MARGIN, STAFF_HEIGHT/*staff edit*/);
-    if(curstaff==si->currentstaff) {
+
       if(staff->staff_directives) {
 
 	guint width = gdk_pixbuf_get_width( GDK_PIXBUF(StaffPixbuf));
@@ -751,7 +760,7 @@ draw_score (GtkWidget * widget, DenemoGUI * gui)
 	guint height = gdk_pixbuf_get_height( GDK_PIXBUF(StaffPixbuf));
 	gdk_draw_pixbuf(gui->pixmap, NULL, StaffPixbuf,  0,0, 0,y + STAFF_HEIGHT/2, width, height, GDK_RGB_DITHER_NONE,0,0/*staff edit*/);
       }
-    }
+    
     
 
 
@@ -765,6 +774,12 @@ draw_score (GtkWidget * widget, DenemoGUI * gui)
     }
     if(si->currentstaffnum==itp.staffnum)
       reset_lyrics(staff, count_syllables(staff, si->leftmeasurenum));
+    
+    //allocate wronglength[] large enough for si->rightmeasurenum - si->leftmeasurenum entries then put it in itp
+    // and set it in draw_measure
+
+    gboolean *wronglength = (gboolean *)g_malloc((sizeof(gboolean))*(2+si->rightmeasurenum - si->leftmeasurenum));
+    itp.wronglengths = wronglength;
     draw_staff (staff, y, gui, &itp);
 
     //IN FACT itp.highy is only set by one measure, it is reset to zero in the measure loop
@@ -773,35 +788,39 @@ draw_score (GtkWidget * widget, DenemoGUI * gui)
     if(itp.lowy>lowy && itp.lowy<MAXEXTRASPACE)
       staff->space_below = itp.lowy, repeat=TRUE;
 
-
+    gint measures_in_staff = g_list_length(staff->measures);
     /* Now draw the barlines between the measures, across all the staffs */
     mwidthiterator = g_list_nth (si->measurewidths, si->leftmeasurenum - 1);
     for (x = KEY_MARGIN + si->maxkeywidth + 
 	   SPACE_FOR_TIME - HALF_BARLINE_SPACE,
-	   i = si->leftmeasurenum;
-	 i <= si->rightmeasurenum; mwidthiterator = mwidthiterator->next, 
+	   i = si->leftmeasurenum; mwidthiterator && 
+	   (i <= si->rightmeasurenum); mwidthiterator = mwidthiterator->next, 
 	   i++)
       {
+
 	gint top = y + STAFF_HEIGHT; 
 
 	x += GPOINTER_TO_INT (mwidthiterator->data) + SPACE_FOR_BARLINE;
-	   
-	if (!mwidthiterator->next) /* Last measure - draw double-barline */
+	if(i==measures_in_staff)
+	  mwidthiterator = g_list_last(si->measurewidths);//do not draw barlines for short staffs
+	if (!mwidthiterator->next) /* Last measure - draw light line 3 pixels early */
 	  x -= 3;
-	gdk_draw_line (gui->pixmap, graygc, x, top, x, y);
-	   
+	gdk_draw_line (gui->pixmap, wronglength[i-si->leftmeasurenum]?graygc:blackgc, x, top, x, y);
+	
 	if (!mwidthiterator->next)
 	  {
-	    /* Again, we've reached the end of the score and should
-	     * draw a double-barline */
+	    /* we've reached the end of the score and should
+	     * draw the heavy part of double-barline at regular position */
 	    x += 3;
-	    gdk_draw_rectangle (gui->pixmap, blackgc, TRUE, x,
+	    gdk_draw_rectangle (gui->pixmap, wronglength[i-si->leftmeasurenum]?graygc:blackgc, TRUE, x,
 				y, 4,
 				STAFF_HEIGHT+1);
 	  }
 	   
       }
 
+
+    g_free(wronglength);
     if ( itp.staffnum < si->bottom_staff
 	 &&    ((DenemoStaff *) curstaff->next->data)->voicenumber !=2)
       {
@@ -835,6 +854,11 @@ gint
 scorearea_expose_event (GtkWidget * widget, GdkEventExpose * event)
 {
 DenemoGUI *gui = Denemo.gui;
+ if((!Denemo.gui->si)||(!Denemo.gui->si->currentmeasure)){
+   g_warning("Cannot draw!\n");
+   return TRUE;
+ }
+
  do{
    /* Clear the backing pixmap */
    if(Denemo.gui->input_source!=INPUTKEYBOARD &&
