@@ -19,10 +19,11 @@
  *
  */
 void
-draw_cursor (GdkPixmap * pixmap, struct scoreinfo *si,
-	     gint xx, gint y, gint dclef)
+draw_cursor (GdkPixmap * pixmap, DenemoScore * si,
+	     gint xx, gint y, input_mode mode, gint dclef)
 {
   gint height = calculateheight (si->cursor_y, dclef);
+
   static GdkGC *blackgc = NULL;
   static GdkGC *graygc;
   static GdkGC *greengc;
@@ -41,9 +42,9 @@ draw_cursor (GdkPixmap * pixmap, struct scoreinfo *si,
       purplegc = gcs_purplegc ();
     }
 
-  paintgc = (si->mode == INPUTREST) ? graygc :
-    (si->mode == INPUTBLANK ) ? bluegc :
-    (si->mode == REPLACE) ? purplegc : si->cursoroffend ? redgc : greengc;
+  paintgc = (mode & INPUTREST) ? graygc :
+    (mode & INPUTBLANK) ? bluegc :
+    (mode & INPUTEDIT) ? purplegc : si->cursoroffend ? redgc : greengc;
   gdk_draw_rectangle (pixmap, paintgc, TRUE, xx, height + y - CURSOR_MINUS,
 		      CURSOR_WIDTH, CURSOR_HEIGHT);
 
