@@ -28,11 +28,11 @@ draw_lily_dir (GdkPixmap * pixmap, GdkGC * gc, GdkFont * font,
   if(lily->graphic){
     gint width = lily->width;
     gint  height = lily->height;  
-    drawbitmapinverse (pixmap, gc, lily->graphic,
+    drawbitmapinverse (pixmap, gc, (GdkBitmap *)lily->graphic,
 		     xx + lily->gx, y + lily->gy, width, height);
   }
   else
-    gdk_draw_rectangle (pixmap, selected?gcs_bluegc():gcs_greengc(), TRUE, xx, y+3*STAFF_HEIGHT/2, 2, STAFF_HEIGHT/2);
+    gdk_draw_rectangle (pixmap, selected?gcs_bluegc():gcs_greengc(), TRUE, xx-2, y, 4, STAFF_HEIGHT);
   if(lily->display) {  //store display position x,y as well
     pango_layout_set_text (layout,
 			   lily->display->str,
