@@ -338,6 +338,8 @@ midi_delta (FILE * fd, long delta, int more)
   return sz;
 }
 
+
+#if 0
 /**
  * this is used by several meta events
  */
@@ -369,6 +371,11 @@ midi_meta_text (int metatype, char *string)
   return event; 
 }
 
+#else
+#define midi_meta_text(a,b) smf_event_new_textual(a,b)
+#endif
+
+
 /**
  * put two strings and a number in a midi comment (debug)
  */
@@ -952,11 +959,22 @@ static gint directive_get_midi_interpretation(DenemoDirective *directive) {
 static gint directive_get_midi_action(DenemoDirective *directive) {	
   return directive->override&DENEMO_MIDI_ACTION_MASK;
 }
-
-static gchar *directive_get_midi_buffer(DenemoDirective *directive, gint *pnumbytes) {		    
+gchar *substitute_midi_values(gchar* str, gint channel, gint volume) {
+  gchar *bytes = g_strdup(str);
+  gchar *c;
+  for(c=bytes;*c;c++) {
+    if(*c=='$')
+      *c = '0'+channel-1;
+    if(*c=='%' && *(c+1)=='%' && *(c+2)=='%')
+      sprintf(c, "%3d", volume);//*c = itoa(volume);
+  }
+  //  g_print("We have transformed %s to %s\n", str, bytes);
+  return bytes;
+}
+static gchar *directive_get_midi_buffer(DenemoDirective *directive, gint *pnumbytes, gint channel, gint volume) {		    
   if(directive->midibytes) {
     gchar *bytes;
-    bytes = directive->midibytes->str;
+    bytes = substitute_midi_values(directive->midibytes->str, channel, volume);
     //g_print("Got %s as midi bytes\n", bytes);
     char *next;
     char val;
@@ -985,6 +1003,7 @@ static gchar *directive_get_midi_buffer(DenemoDirective *directive, gint *pnumby
       //g_print("byte %x\n", buffer[i]);
     }
     *pnumbytes = numbytes;
+    g_free(bytes);
     return buffer;
   }
   return NULL;
@@ -1027,6 +1046,31 @@ change_volume(gint *volume, gint midi_val, gint  midi_interpretation,gint  midi_
   if(*volume>127) *volume=127;
   if(*volume<0) *volume=0;
 }
+
+
+/* change the channel according to the values passed in */
+static void 
+change_channel(gint *channel, gint midi_val, gint  midi_interpretation,gint  midi_action)
+{
+  gdouble val;
+  // g_print("midi_val %d cur_channel %d\n", midi_val, cur_channel);
+  val = (gdouble) midi_val;
+  if(midi_interpretation & DENEMO_OVERRIDE_PERCENT)
+    g_warning("Percent meaningless with channel change");
+  if(midi_action == DENEMO_OVERRIDE_ONCE)
+    g_warning("Scripting error, ONCE for standalone directive is meaningless");
+  if(midi_action == DENEMO_OVERRIDE_RAMP)
+    g_warning("Ramp meaningless with channel change");
+  if(midi_action == DENEMO_OVERRIDE_STEP) {
+      *channel = val;
+  }  
+  if(*channel>127) *channel=127;
+  if(*channel<0) *channel=0;
+}
+
+
+
+
 /* change the tempo according to the values passed in */
 static void 
 change_tempo(gint *tempo, gint midi_val, gint  midi_interpretation,gint  midi_action)
@@ -1188,7 +1232,7 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 	  gint numbytes;
 	  directive = (DenemoDirective *)g->data;
 	  gint midi_override = directive_get_midi_override(directive);
-	  gchar *buffer = directive_get_midi_buffer(directive, &numbytes);
+	  gchar *buffer = directive_get_midi_buffer(directive, &numbytes, midi_channel, cur_volume);
 	  if(midi_override)
 	    g_warning("No MIDI override values mean anything at Staff level");
 	      if(buffer) 
@@ -1206,7 +1250,7 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 	    gint numbytes;
 	    directive = (DenemoDirective *)g->data;
 	    gint midi_override = directive_get_midi_override(directive);
-	    gchar *buffer = directive_get_midi_buffer(directive, &numbytes);
+	    gchar *buffer = directive_get_midi_buffer(directive, &numbytes, midi_channel, cur_volume);
 	    if(midi_override)
 	      g_warning("No MIDI override values mean anything at Score level");
 	    if(buffer) 
@@ -1222,7 +1266,7 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 	    gint numbytes;
 	    directive = (DenemoDirective *)g->data;
 	    gint midi_override = directive_get_midi_override(directive);
-	    gchar *buffer = directive_get_midi_buffer(directive, &numbytes);
+	    gchar *buffer = directive_get_midi_buffer(directive, &numbytes, midi_channel, cur_volume);
 	    if(midi_override)
 	      g_warning("No MIDI override values mean anything at Movement level");
 	    if(buffer) 
@@ -1274,7 +1318,7 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
       }
 
       /* set selected midi program */
-      g_print("Using channel %d\n", midi_channel);
+      g_print("Using channel %d prognum %d\n", midi_channel, prognum);
       event = midi_change_event (MIDI_PROG_CHANGE, midi_channel, prognum);
       smf_track_add_event_delta_pulses(track, event, 0);
 
@@ -1372,7 +1416,7 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 			for(g=chordval.directives;g;g=g->next){
 			  gint numbytes;
 			  directive = (DenemoDirective *)g->data;
-			  gchar *buffer = directive_get_midi_buffer(directive, &numbytes);
+			  gchar *buffer = directive_get_midi_buffer(directive, &numbytes, midi_channel, cur_volume);
 			  gint midi_override = directive_get_midi_override(directive);
 			  gint midi_interpretation = directive_get_midi_interpretation(directive);
 			  gint midi_action = directive_get_midi_action(directive);
@@ -1383,6 +1427,9 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 			    case DENEMO_OVERRIDE_VOLUME:
 				change_volume(&cur_volume, midi_val, midi_interpretation, midi_action);
 			      break;
+			    case DENEMO_OVERRIDE_CHANNEL:
+				change_channel(&midi_channel, midi_val, midi_interpretation, midi_action);
+			      break;
 			    case DENEMO_OVERRIDE_TEMPO:
 			      change_tempo(&cur_tempo, midi_val, midi_interpretation, midi_action);
 			      if(cur_tempo) {
@@ -1439,6 +1486,8 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 	  /********************************
 	   * compute real duration of note
 	   ********************************/
+#if 0
+		  //this is not working - it causes the delta to be -ve later
 		  for (tmp = chordval.ornamentlist; tmp; tmp = tmp->next)
 		    {
 		      if (*(enum ornament *) tmp->data ==
@@ -1453,16 +1502,20 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 			  width = percent (duration, pref_staccato);
 			  tmpstaccato = 1;
 			}
-#if 0
+
 		      else
 			{
 			  width = percent (duration, pref_width);
 			}
-#endif
+
 		    }
 		  if (debug)
 		    fprintf (stderr, "duration is %s\n",
 			     fmt_ticks (duration));
+
+#endif
+
+
 		  if (chordval.notes)
 		    {
 
@@ -1615,8 +1668,9 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 				  ticks_written += duration + width;
 				  if (ticks_written > ticks_read + duration)
 				    {
-				      fprintf (stderr, "BAD WIDTH %d\n"
-					       "(should not happen!)", width);
+				      fprintf (stderr, "BAD WIDTH %d so delta %d\n"
+					       "(should not happen!)", width, mididelta);
+				      mididelta = 0;
 				    }
 				}
 			      else
@@ -1764,7 +1818,7 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 		case LILYDIRECTIVE:
 		  {
 		    gint numbytes;
-		    gchar *buffer = directive_get_midi_buffer(curobj->object, &numbytes);
+		    gchar *buffer = directive_get_midi_buffer(curobj->object, &numbytes, midi_channel, cur_volume);
 		    gint midi_override = directive_get_midi_override(curobj->object);
 		    gint midi_interpretation = directive_get_midi_interpretation(curobj->object);
 		    gint midi_action = directive_get_midi_action(curobj->object);
@@ -1774,6 +1828,9 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 		      case  DENEMO_OVERRIDE_VOLUME:
 			change_volume(&cur_volume, midi_val, midi_interpretation, midi_action);
 			break;
+		      case  DENEMO_OVERRIDE_CHANNEL:
+			change_channel(&midi_channel, midi_val, midi_interpretation, midi_action);
+			break;
 		      case DENEMO_OVERRIDE_TEMPO:
 			change_tempo(&cur_tempo, midi_val, midi_interpretation, midi_action);
 			if(cur_tempo) {
