@@ -294,7 +294,14 @@ newXMLFraction (xmlNodePtr parent, xmlNsPtr ns, gint num, gint denom)
   newXMLIntChild (parent, ns, (xmlChar *) "denominator", denom);
 }
 
-
+static void
+newVersesElem(xmlNodePtr curElem,  xmlNsPtr ns, GList *verses, gchar *type) {
+  xmlNodePtr versesElem =  xmlNewChild (curElem, ns, (xmlChar *) type, NULL);
+  for(;verses;verses=verses->next) {
+    GtkWidget *textview = verses->data;
+    xmlNewChild (versesElem, ns, (xmlChar *) "verse", (xmlChar *)get_text_from_view(textview));
+  }
+}
 static void
 newDirectivesElem(xmlNodePtr objElem, xmlNsPtr ns, GList *g, gchar *type) { 
   xmlNodePtr directivesElem =  xmlNewChild (objElem, ns, (xmlChar *) type, NULL);
@@ -312,6 +319,7 @@ newDirectivesElem(xmlNodePtr objElem, xmlNsPtr ns, GList *g, gchar *type) {
     DO_DIREC(prefix);
     DO_DIREC(postfix);
     DO_DIREC(display);
+    DO_DIREC(midibytes);
     DO_DIREC(graphic_name);
     
     DO_INTDIREC(minpixels);
@@ -712,10 +720,12 @@ exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
 			  curStaffStruct->space_below);
 	  newXMLIntChild (curElem, ns, (xmlChar *) "hasfigures",
 			  curStaffStruct->hasfigures);
-	  newXMLIntChild (curElem, ns, (xmlChar *) "haslyrics",
-			  curStaffStruct->haslyrics);
+
 	  newXMLIntChild (curElem, ns, (xmlChar *) "hasfakechords",
 			  curStaffStruct->hasfakechords);
+
+	  if(curStaffStruct->verses)
+	    newVersesElem(curElem, ns, curStaffStruct->verses, "verses"); 
 	  
 	  if(curStaffStruct->staff_prolog && curStaffStruct->staff_prolog->len)
 	     xmlNewChild (curElem, ns, (xmlChar *) "staff-prolog",
@@ -1213,69 +1223,11 @@ exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
 
 			  if(curNote->directives) {
 			    newDirectivesElem(curElem, ns, curNote->directives, "directives");
-#if 0
-			    directivesElem =  xmlNewChild (curElem, ns, (xmlChar *) "directives", NULL);
-			    GList *g = curNote->directives;
-			    for(;g;g=g->next) {
-			      DenemoDirective *directive = (DenemoDirective *)g->data;
-			      directiveElem =  xmlNewChild (directivesElem, ns, (xmlChar *) "directive", NULL);	
-#define DO_DIREC(field)  if (directive->field\
-                   && directive->field->len)\
-                      xmlNewChild (directiveElem, ns, (xmlChar *) #field,\
-				     (xmlChar *) directive->field->str);
 
-#define DO_INTDIREC(field)   newXMLIntChild (directiveElem, ns, (xmlChar *) #field,\
-				             directive->field);
-
-			      DO_DIREC(tag);
-			      DO_DIREC(prefix);
-			      DO_DIREC(postfix);
-			      DO_DIREC(display);
-			      DO_DIREC(graphic_name);
-
-			      DO_INTDIREC(minpixels);
-			      DO_INTDIREC(x);
-			      DO_INTDIREC(y);
-			      DO_INTDIREC(tx);
-			      DO_INTDIREC(ty);
-			      DO_INTDIREC(gx);
-			      DO_INTDIREC(gy);
-			      DO_INTDIREC(override);
-
-
-#undef DO_DIREC
-#undef DO_INTDIREC
-			    }
-#endif
 			  }
 
 			}
 		      }
-
-#if 0
-		  /* If this is the end of a beam, output a <beam-end>. */
-
-		  if (curObj->isend_beamgroup && !curObj->isstart_beamgroup)
-		    {
-		      curElem =
-			xmlNewChild (measureElem, ns, (xmlChar *) "beam-end",
-				     NULL);
-		      if (lastBeamStartXMLID == NULL)
-			{
-			  g_warning
-			    ("Encountered the end of a beam without a "
-			     "beginning");
-			}
-		      else
-			{
-			  xmlSetProp (curElem, (xmlChar *) "beam",
-				      (xmlChar *) lastBeamStartXMLID);
-			  g_free (lastBeamStartXMLID);
-			  lastBeamStartXMLID = NULL;
-			}
-		    }
-#endif
-
 		  }
 		  break;
 
@@ -1423,6 +1375,7 @@ exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
 
 		    SETSTRING_PROP (tag);
 		    SETSTRING_PROP (display);
+		    SETSTRING_PROP (midibytes);
 		    SETSTRING_PROP (graphic_name);
 		    SETSTRING_PROP (prefix);//postfix done above, for backward compatibility
 #undef SETSTRING_PROP
@@ -1437,6 +1390,7 @@ exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
 		    SETINT_PROP (gx);
 		    SETINT_PROP (gy);
 		    SETINT_PROP (minpixels);
+		    SETINT_PROP (override);
 #undef SETINT_PROP		  
 		  break;
 		case BARLINE:
