@@ -265,6 +265,7 @@ open_for_real (gchar * filename, DenemoGUI * gui, gboolean template, ImportType
       refresh_lily_cb(NULL, gui);
     }
   g_signal_handlers_unblock_by_func(G_OBJECT (gui->scorearea), G_CALLBACK (scorearea_expose_event), NULL);
+  load_local_scheme_init();//to re-instate any user defined directives for whole score
   return result;
 }
 
@@ -1081,7 +1082,7 @@ static void selection_received (GtkClipboard *clipboard, const gchar *text, gpoi
     fprintf(fp, "music = { %s }\n\\score {\n\\music\n\\layout {}\n}\n", text);
     fclose(fp);
     gint theclef = find_prevailing_clef(Denemo.gui->si);
-    newtab(NULL, NULL);
+    newview(NULL, NULL);
     gint fail = open_for_real(filename, Denemo.gui, TRUE, REPLACE_SCORE);
     //thescore can be NULL after failed load....
     if(fail) {
