@@ -3,40 +3,56 @@
 #include <jack/jack.h>
 #include <jack/midiport.h>
 #include "midi.h"
-
 #include <glib.h>
 #include <math.h>
 #include <string.h>
 #include <assert.h>
 #include "exportmidi.h"
+#include "jackmidi.h"
 #include "pitchentry.h"
 #include "smf.h"
 #define NOTE_OFF                0x80
 #define NOTE_ON                 0x90
 #define SYS_EXCLUSIVE_MESSAGE1  0xF0
 #define MIDI_CONTROLLER         0xB0
-#define MIDI_ALL_SOUND_OFF      120
+#define MIDI_ALL_SOUND_OFF      0x78 
+#define MIDI_ALL_NOTE_OFF	0x7b
 #define MAX_NUMBER_OF_TRACKS    128
-
+#define BUFFER_MAX_INDEX	100
 #define INPUT_PORT_NAME         "midi_in"
 #define PROGRAM_NAME            "denemo"
 jack_client_t   *jack_client = NULL;
 jack_port_t     *input_port;
 jack_port_t	*output_ports[MAX_NUMBER_OF_TRACKS];
 
+static volatile gint BufferIndex;
+static gint BufferFillIndex;
+static volatile gboolean BufferEmpty = TRUE;
+static volatile gboolean IMMEDIATE = TRUE;
+
+struct midi_buffer
+{
+  unsigned char buffer[3];
+  gint channel;
+  gint jack_port;
+};
+
+struct midi_buffer global_midi_buffer[BUFFER_MAX_INDEX]; 
+
 static gint timeout_id = 0, kill_id=0;
-static gdouble duration = 0.0;
+static gdouble playback_duration = 0.0;
 
-static smf_t           *smf = NULL;
-static double          rate_limit = 0;
-static int             just_one_output = 0;
-static int             start_stopped = 0;
-static int             use_transport = 0;
-static int             be_quiet = 1;
+static smf_t           	*smf = NULL;
+static double          	rate_limit = 0;
+static gboolean        	just_one_output = FALSE;
+static gboolean        	start_stopped = FALSE;
+static gboolean        	use_transport = FALSE;
+
+static int    		playback_started = -1, song_position = 0;
+static gboolean 	stop_midi_output = FALSE;
+static double 		start_time = 0.0;//time in seconds to start at (from start of the smf)
+static double 		end_time = 0.0;//time in seconds to end at (from start of the smf)
 
-static int    playback_started = -1, song_position = 0, stop_midi_output = 0;
-static double start_time = 0.0;//time in seconds to start at (from start of the smf)
-static double end_time = 0.0;//time in seconds to end at (from start of the smf)
 double 
 get_time(void)
 {
@@ -81,9 +97,9 @@ get_delta_time(void)
 static gboolean
 warning_async(gpointer s)
 {
-	const char *str = (const char *)s;
+	gchar *str = (gchar *)s;
 
-	g_warning(str);
+	g_warning("%s", str);
 
 	return FALSE;
 }
@@ -91,7 +107,9 @@ warning_async(gpointer s)
 static void
 warn_from_jack_thread_context(const char *str)
 {
+#ifdef DEBUG
 	g_idle_add(warning_async, (gpointer)str);
+#endif
 }
 
 static double
@@ -135,7 +153,6 @@ send_all_sound_off(void *port_buffers[MAX_NUMBER_OF_TRACKS], jack_nframes_t nfra
 {
 	int i, channel;
 	unsigned char *buffer;
-	if(!be_quiet)
 	warn_from_jack_thread_context("\nSending all sound off!!!\n");
 	for (i = 0; i < smf->number_of_tracks; i++) {
 		for (channel = 0; channel < 16; channel++) {
@@ -158,23 +175,94 @@ send_all_sound_off(void *port_buffers[MAX_NUMBER_OF_TRACKS], jack_nframes_t nfra
 			break;
 	}
 }
-static gint move_on(DenemoGUI *gui){
-	  if(timeout_id==0)
-		      return FALSE;
-	    set_currentmeasurenum (gui, gui->si->currentmeasurenum+1);
 
-	      return TRUE;
+static gint move_on(DenemoGUI *gui){
+  if(timeout_id==0)
+    return FALSE;
+  set_currentmeasurenum (gui, gui->si->currentmeasurenum+1);
+  return TRUE;
 }
 
 gint jack_kill_timer(void){
   g_debug("Jack kill timer %d\n", timeout_id);
-if(timeout_id>0)
-  g_source_remove(timeout_id);
-timeout_id= 0;
-if(kill_id)
-  g_source_remove(kill_id);
-kill_id = 0;
-return 1;
+  if(timeout_id>0)
+    g_source_remove(timeout_id);
+  timeout_id = 0;
+  if(kill_id)
+    g_source_remove(kill_id);
+  kill_id = 0;
+  return 1;
+}
+
+static gboolean
+timer_callback(gpointer bufferindex){
+       gint index = (gint) bufferindex;
+       global_midi_buffer[BufferFillIndex].buffer[0] = NOTE_OFF | global_midi_buffer[index].channel;
+       global_midi_buffer[BufferFillIndex].buffer[1] = global_midi_buffer[index].buffer[1];
+       global_midi_buffer[BufferFillIndex].buffer[2] = global_midi_buffer[index].buffer[2];
+       global_midi_buffer[BufferFillIndex].jack_port = global_midi_buffer[index].jack_port;
+       BufferFillIndex = BufferFillIndex+1 > BUFFER_MAX_INDEX ? 0 : BufferFillIndex+1;
+       BufferEmpty=FALSE;
+       return FALSE;
+}
+
+void 
+jack_playpitch(gint key, gint duration){
+ if (BufferEmpty==TRUE){ 
+    DenemoStaff *curstaffstruct = (DenemoStaff *) Denemo.gui->si->currentstaff->data;
+    global_midi_buffer[BufferFillIndex].buffer[0] = NOTE_ON | curstaffstruct->midi_channel;
+    global_midi_buffer[BufferFillIndex].buffer[1] = key; 
+    global_midi_buffer[BufferFillIndex].buffer[2] = curstaffstruct->volume;
+    global_midi_buffer[BufferFillIndex].channel = curstaffstruct->midi_channel;
+    global_midi_buffer[BufferFillIndex].jack_port = curstaffstruct->jack_midi_out_port;
+    g_timeout_add(duration, timer_callback, (gpointer) BufferFillIndex);
+    BufferFillIndex = BufferFillIndex+1 > BUFFER_MAX_INDEX ? 0 : BufferFillIndex+1;
+    BufferEmpty=FALSE;
+  }
+}
+
+void jack_output_midi_event(unsigned char *buffer){
+ if (BufferEmpty==TRUE){ 
+   global_midi_buffer[BufferFillIndex].buffer[0] = buffer[0];
+   global_midi_buffer[BufferFillIndex].buffer[1] = buffer[1];
+   global_midi_buffer[BufferFillIndex].buffer[2] = buffer[2];
+   BufferFillIndex = BufferFillIndex+1 > BUFFER_MAX_INDEX ? 0 : BufferFillIndex+1;
+   if (BufferFillIndex == BufferIndex)
+     g_debug("\nBuffer Overrun\n");
+   BufferEmpty=FALSE;
+ }
+ else {
+   global_midi_buffer[BufferFillIndex].buffer[0] = buffer[0];
+   global_midi_buffer[BufferFillIndex].buffer[1] = buffer[1];
+   global_midi_buffer[BufferFillIndex].buffer[2] = buffer[2];
+   BufferFillIndex = BufferFillIndex+1 > BUFFER_MAX_INDEX ? 0 : BufferFillIndex+1;
+ }
+}
+
+static void
+send_midi_event(jack_nframes_t nframes){
+  unsigned char *buffer;
+  gint i=global_midi_buffer[BufferIndex].jack_port;
+  void *port_buffers[MAX_NUMBER_OF_TRACKS];
+
+  if (output_ports[i]){
+   port_buffers[i] = jack_port_get_buffer(output_ports[i], nframes);
+   jack_midi_clear_buffer(port_buffers[i]);
+   if (BufferEmpty==FALSE)
+     while (BufferIndex != BufferFillIndex){
+       buffer = jack_midi_event_reserve(port_buffers[i], 0, 3);
+       if (buffer == NULL){
+         warn_from_jack_thread_context("jack_midi_event_reserve_failed, NOTE_LOST.");
+         return;
+       }
+       buffer[0] = global_midi_buffer[BufferIndex].buffer[0];
+       buffer[1] = global_midi_buffer[BufferIndex].buffer[1];
+       buffer[2] = global_midi_buffer[BufferIndex].buffer[2];
+       BufferIndex = BufferIndex+1 > BUFFER_MAX_INDEX ? 0 : BufferIndex+1; 
+     }
+     BufferEmpty=TRUE;
+   
+  }
 }
 
 static void
@@ -184,8 +272,6 @@ process_midi_output(jack_nframes_t nframes)
 	unsigned char  *buffer, tmp_status;
 	void		*port_buffers[MAX_NUMBER_OF_TRACKS];
 	jack_nframes_t	last_frame_time;
-	jack_transport_state_t transport_state;
-	static jack_transport_state_t previous_transport_state = JackTransportStopped;
 	smf_event_t *n;
 	for (i = 0; i < smf->number_of_tracks; i++) {
 	  if(output_ports[i])
@@ -206,24 +292,16 @@ process_midi_output(jack_nframes_t nframes)
 			break;
 	}
  
-	if (use_transport) {
-		transport_state = jack_transport_query(jack_client, NULL);
-		if (transport_state == JackTransportStopped) {
-			if (previous_transport_state == JackTransportRolling)
-				send_all_sound_off(port_buffers, nframes);
-
-			previous_transport_state = transport_state;
-
-			return;
-		}
-
-		previous_transport_state = transport_state;
-	}
-	
+	if (use_transport) 
+	  if (JackTransportStopped == jack_transport_query(jack_client, NULL))
+		  return;
+		
 	last_frame_time = jack_last_frame_time(jack_client);
 	/* End of song already? */
-	if (playback_started < 0)
+	if (playback_started < 0){
+		warn_from_jack_thread_context/*g_debug*/("playback_started < 0");
 		return;
+	}
 	/* We may push at most one byte per 0.32ms to stay below 31.25 Kbaud limit. */
 	bytes_remaining = nframes_to_ms(nframes) * rate_limit;
 
@@ -231,28 +309,14 @@ process_midi_output(jack_nframes_t nframes)
 		smf_event_t *event = smf_peek_next_event(smf);
 
 		if (event == NULL || (event->time_seconds>end_time)) {
-		        if (!be_quiet)
-			  warn_from_jack_thread_context/*g_debug*/("End of song.");
-			playback_started = -1;
-
-			if (!use_transport)
-				stop_midi_output = 1;
-
-			break;
-		}
-
-	        if (stop_midi_output > 0) {
+			warn_from_jack_thread_context/*g_debug*/("End of song.");
+			jack_midi_playback_stop();
 			send_all_sound_off(port_buffers, nframes);
-			jack_transport_stop(jack_client);	
-			return;
+			break;
 		}
 		
 		/* Skip over metadata events. */
 		if (smf_event_is_metadata(event)) {
-			char *decoded = smf_event_decode(event);
-			if (decoded && !be_quiet)
-				warn_from_jack_thread_context/*g_debug*/(g_strdup_printf("Metadata: %s", decoded));
-
 			n = smf_get_next_event(smf);
 			continue;
 		}
@@ -264,7 +328,6 @@ process_midi_output(jack_nframes_t nframes)
 		}
 
 		t = seconds_to_nframes(event->time_seconds - start_time) + playback_started - song_position + nframes - last_frame_time;
-
 		/* If computed time is too much into the future, we'll need
 		   to send it later. */
 		if (t >= (int)nframes)
@@ -274,31 +337,9 @@ process_midi_output(jack_nframes_t nframes)
 		if (t < 0)
 			t = 0;
 
-		assert(event->track->track_number >= 0 && event->track->track_number <= MAX_NUMBER_OF_TRACKS);
-
 		/* We will send this event; remove it from the queue. */
 		n = smf_get_next_event(smf);
 
-		/* First, send it via midi_out. */
-		track_number = 0;
-
-#ifdef JACK_MIDI_NEEDS_NFRAMES
-		buffer = jack_midi_event_reserve(port_buffers[track_number], t, event->midi_buffer_length, nframes);
-#else
-		buffer = jack_midi_event_reserve(port_buffers[track_number], t, event->midi_buffer_length);
-#endif
-
-		if (buffer == NULL) {
-			warn_from_jack_thread_context("jack_midi_event_reserve failed, NOTE LOST.");
-			break;
-		}
-
-		memcpy(buffer, event->midi_buffer, event->midi_buffer_length);
-
-		/* Ignore per-track outputs? */
-		if (just_one_output)
-			continue;
-
 		/* Send it via proper output port. */
 		track_number = event->track->track_number -1;
 
@@ -312,20 +353,10 @@ process_midi_output(jack_nframes_t nframes)
 			warn_from_jack_thread_context("jack_midi_event_reserve failed, NOTE LOST.");
 			break;
 		}
-
-		/* Before sending, reset channel to 0. XXX: Not very pretty. */
-		assert(event->midi_buffer_length >= 1);
-
-		tmp_status = event->midi_buffer[0];
-
-		if (event->midi_buffer[0] >= 0x80 && event->midi_buffer[0] <= 0xEF)
-			event->midi_buffer[0] &= 0xF0;
-
 		memcpy(buffer, event->midi_buffer, event->midi_buffer_length);
-
-		event->midi_buffer[0] = tmp_status;
 	}
 }
+
 void
 static process_midi_input(jack_nframes_t nframes)
 {
@@ -347,52 +378,17 @@ static process_midi_input(jack_nframes_t nframes)
 static int 
 process_callback(jack_nframes_t nframes, void *notused)
 {
-#ifdef MEASURE_TIME
-	if (get_delta_time() > MAX_TIME_BETWEEN_CALLBACKS) {
-		warn_from_jack_thread_context("Had to wait too long for JACK callback; scheduling problem?");
-	}
-#endif
-
-	/* Check for impossible condition that actually happened to me, caused by some problem between jackd and OSS4. */
-	if (nframes <= 0) {
-		warn_from_jack_thread_context("Process callback called with nframes = 0; bug in JACK?");
-		return 0;
-	}
-
-	process_midi_input(nframes);
-	if (Denemo.gui->si && Denemo.gui->si->smf && output_ports){
-	  process_midi_output(nframes);
-	}
-#ifdef MEASURE_TIME
-	if (get_delta_time() > MAX_PROCESSING_TIME) {
-		warn_from_jack_thread_context("Processing took too long; scheduling problem?");
-	}
-#endif
-
-	return 0;
-}
-
-static int
-sync_callback(jack_transport_state_t state, jack_position_t *position, void *notused)
-{
-	assert(jack_client);
-
-	/* XXX: We should probably adapt to external tempo changes. */
-
-	if (state == JackTransportStarting) {
-		song_position = position->frame;
-		int n = smf_seek_to_seconds(smf, nframes_to_seconds(position->frame));
-
-		if (!be_quiet)
-			g_debug("Seeking to %f seconds.", nframes_to_seconds(position->frame));
-
-		playback_started = jack_frame_time(jack_client);
-
-	} else if (state == JackTransportStopped) {
-		playback_started = -1;
-	}
-
-	return TRUE;
+  if (nframes <= 0) {
+    warn_from_jack_thread_context("Process callback called with nframes = 0; bug in JACK?");
+    return 0;
+  }
+  if(Denemo.gui->input_source==INPUTMIDI && input_port)
+    process_midi_input(nframes);
+  if (IMMEDIATE && Denemo.gui->si && output_ports)
+      send_midi_event(nframes);
+  if (!IMMEDIATE && Denemo.gui->si && smf && output_ports)
+      process_midi_output(nframes);
+  return 0;
 }
 
 /* returns the jack midi port number that
@@ -553,53 +549,44 @@ jack_midi_player (void) {
 
   if (smf->number_of_tracks > MAX_NUMBER_OF_TRACKS) { 
      g_warning("Number of tracks (%d) exceeds maximum for per-track output; implying '-s' option.", smf->number_of_tracks);
-     just_one_output = 1;
+     just_one_output = TRUE;
   }
   g_debug("\nNumber of tracks = %d\n", smf->number_of_tracks);
- 
-  if (use_transport) {
-    gint err = jack_set_sync_callback(jack_client, sync_callback, 0);
-    if (err) {
-      g_critical("Could not register JACK sync callback.");
-    }
-  }
-  assert(smf->number_of_tracks >= 1);
 
-  if (use_transport && !start_stopped) {
+ if (use_transport && !start_stopped) {
     jack_transport_locate(jack_client, 0);
     jack_transport_start(jack_client);
   }
-  
-  if (!use_transport)
-    playback_started = jack_frame_time(jack_client);
+
+  playback_started = jack_frame_time(jack_client);
+  IMMEDIATE=FALSE;
 }
 
 void
 jack_midi_playback_start()
 {
   DenemoGUI *gui = Denemo.gui;
-  playback_started = -1, song_position = 0, stop_midi_output = 0;
+  playback_started = -1, song_position = 0, stop_midi_output = FALSE;
+  
   /* set tranport on/off */
-  use_transport = (int)Denemo.prefs.jacktransport; 
-  /* set tranport start_stopped */
-  start_stopped = (int)Denemo.prefs.jacktransport_start_stopped; 
-  g_debug("\nTransport set to %d Transport start stopped = %d\n", 
-		  use_transport, start_stopped);
+  use_transport = (gboolean)Denemo.prefs.jacktransport; 
+  /* set transport start_stopped */
+  start_stopped = (gboolean) Denemo.prefs.jacktransport_start_stopped; 
   if (jack_client != NULL){
      if((gui->si->smf==NULL) || (gui->si->smfsync!=gui->si->changecount))
        exportmidi (NULL, gui->si, 1, 0/* means to end */);
 
-	 
+ 
 
 
 	  smf = Denemo.gui->si->smf;
 	  if (smf == NULL) {
-	    g_critical("Loading SMF file failed.");
+	    g_critical("Loading SMF failed.");
 	    return;
 	  }
-	  duration = smf_get_length_seconds(smf);
-	  if (!be_quiet)
-	    g_message("%s.", smf_decode(smf));
+	  smf_rewind(smf);
+	  playback_duration = smf_get_length_seconds(smf);
+	  g_debug("%s.\n", smf_decode(smf));
 
 
 
@@ -611,15 +598,15 @@ jack_midi_playback_start()
 	  if(curobj && curobj->midi_events) {
 	    smf_event_t *event = curobj->midi_events->data;
 	    start_time = event->time_seconds;
-	    g_print("setting start %f\n", start_time);
+	    g_debug("\nsetting start %f\n", start_time);
 	  }
-	  end_time = duration;
+	  end_time = playback_duration;
 	  curobj = NULL;
 	  curobj =  get_point_object();
-	  if(curobj && curobj->midi_events) {
+	  if(curobj && curobj->midi_events)/*is this ever true?*/ { 
 	    smf_event_t *event = g_list_last(curobj->midi_events)->data;
 	    end_time = event->time_seconds;
-	    g_print("setting end %f\n", end_time);	   
+	    g_debug("\nsetting end %f\n", end_time);	   
 	    //could investigate to see if event is NoteOn and g_warning("Setting stop time to a NoteOn event!");
 	  } 
 
@@ -629,9 +616,8 @@ jack_midi_playback_start()
 	    start_time = end_time;
 	    end_time = temp;
 	  }
-	  duration = end_time - start_time;
-	  g_print("start %f for %f seconds\n",start_time, duration);
-	  int n = smf_seek_to_seconds(smf, start_time);
+	  playback_duration = end_time - start_time;
+	  g_debug("\nstart %f for %f seconds\n",start_time, playback_duration);
 	  /* execute jackmidi player function */ 
 	  jack_midi_player();
 
@@ -641,7 +627,7 @@ jack_midi_playback_start()
 	      //FIXME add a delay before starting the timer.
 	      timeout_id = g_timeout_add ( 4*((double)staff->timesig.time1/(double)staff->timesig.time2)/(gui->si->tempo/(60.0*1000.0)), (GSourceFunc)move_on, gui);
 	      // g_print("Setting end time to %f %u\n", duration*1000, (guint)(duration*1000));
-	      kill_id = g_timeout_add ((guint)(duration*1000), (GSourceFunc)jack_kill_timer, NULL);
+	      kill_id = g_timeout_add ((guint)(playback_duration*1000), (GSourceFunc)jack_kill_timer, NULL);
 	    }
   }//if jack_client  
   return;
@@ -650,9 +636,12 @@ jack_midi_playback_start()
 void
 jack_midi_playback_stop ()
 {
-   stop_midi_output = 1;
+   stop_midi_output = TRUE;
    if(jack_client)
      jack_transport_stop(jack_client);
+   g_debug("\nStopping Transport and midi playback\n");
+   playback_started = -1;
+   IMMEDIATE=TRUE;
 }
 
 
