@@ -2,6 +2,7 @@
  * Implements lilydirectives which are not notes 
  *
  * for Denemo, a gtk+ frontend to GNU Lilypond
+ * Richard Shann 2009
  * A Tee  (c) 2000-2005
  */
 #include <stdio.h>
@@ -107,6 +108,8 @@ delete_directive(GList **directives, gchar *tag) {
       if(directive->tag && !strcmp(tag, directive->tag->str)){
 	*directives = g_list_remove(*directives, directive);
 	free_directive(directive);
+	score_status(Denemo.gui, TRUE);
+	displayhelper (Denemo.gui);
 	return TRUE;
       }
     }
@@ -782,6 +785,37 @@ what##_directive_get_##field(gchar *tag) {\
 typedef DenemoStaff staff;
 typedef DenemoStaff voice;
 typedef DenemoLilyControl score;
+
+
+
+     //note I think you cannot change the graphic once you have set it.
+#define PUT_GRAPHIC_NAME(what, directives) gboolean \
+what##_directive_put_graphic(gchar *tag, gchar *value) {\
+  what *current = get_##what();\
+  if(current==NULL) return FALSE;\
+  if(current->directives==NULL)\
+       create_directives (&current->directives, tag);\
+  DenemoDirective *directive = get_##what##_directive(tag);\
+  if(directive==NULL){\
+    directive=new_directive(tag);\
+    current->directives = g_list_append(current->directives, directive);\
+    }\
+  loadGraphicItem(value, (GdkBitmap **)&directive->graphic, &directive->width, &directive->height);\
+  if(directive->graphic_name)\
+     g_string_assign(directive->graphic_name, value);\
+  else\
+      directive->graphic_name = g_string_new(value);\
+  return TRUE;\
+}
+#define PUT_GRAPHIC(what) PUT_GRAPHIC_NAME(what, directives)
+PUT_GRAPHIC(chord);
+PUT_GRAPHIC(note);
+
+PUT_GRAPHIC(keysig)
+PUT_GRAPHIC(timesig)
+
+
+
 #define PUT_STR_FIELD_FUNC_NAME(what, field, name)\
 gboolean \
 what##_directive_put_##field(gchar *tag, gchar *value) {\
@@ -798,6 +832,8 @@ what##_directive_put_##field(gchar *tag, gchar *value) {\
     g_string_assign(directive->field, value);\
   else\
     directive->field = g_string_new(value);\
+  widget_for_directive(directive, (void(*)())what##_directive_put_graphic);\
+  g_object_set_data(G_OBJECT(directive->widget), "directives-pointer", &current->name);\
   return TRUE;\
 }
 
@@ -895,6 +931,8 @@ what##_directive_put_##field(gchar *tag, gint value) {\
     current->name = g_list_append(current->name, directive);\
     }\
   directive->field = value;\
+  widget_for_directive(directive, (void(*)())what##_directive_put_graphic);\
+  g_object_set_data(G_OBJECT(directive->widget), "directives-pointer", &current->name);\
   return TRUE;\
 }
 #define PUT_INT_FIELD_FUNC(what, field)  PUT_INT_FIELD_FUNC_NAME(what, field, directives)
@@ -1057,30 +1095,6 @@ GET_INT_FIELD_FUNC(standalone, height)
 GET_INT_FIELD_FUNC(score, height)
 
 
-
-     //note I think you cannot change the graphic once you have set it.
-#define PUT_GRAPHIC_NAME(what, directives) gboolean \
-what##_directive_put_graphic(gchar *tag, gchar *value) {\
-  what *current = get_##what();\
-  if(current==NULL) return FALSE;\
-  if(current->directives==NULL)\
-       create_directives (&current->directives, tag);\
-  DenemoDirective *directive = get_##what##_directive(tag);\
-  if(directive==NULL){\
-    directive=new_directive(tag);\
-    current->directives = g_list_append(current->directives, directive);\
-    }\
-  loadGraphicItem(value, (GdkBitmap **)&directive->graphic, &directive->width, &directive->height);\
-  if(directive->graphic_name)\
-     g_string_assign(directive->graphic_name, value);\
-  else\
-      directive->graphic_name = g_string_new(value);\
-  return TRUE;\
-}
-#define PUT_GRAPHIC(what) PUT_GRAPHIC_NAME(what, directives)
-PUT_GRAPHIC(chord);
-PUT_GRAPHIC(note);
-
 /* return a full path to an editscript for directive or NULL if there is none */
 static gchar *get_editscript_filename(gchar *tag) {
 gchar *basename = g_strconcat(tag, ".scm", NULL);
@@ -1102,181 +1116,250 @@ gchar *basename = g_strconcat(tag, ".scm", NULL);
   return filename;
 }
 
-static void
-runscript_callback (GtkWidget *w, DenemoDirective *directive){
-gchar *editscript = get_editscript_filename(directive->tag->str);
- if(editscript)
-   execute_script_file(editscript);
- else
-   g_warning("Editscript has vanished");
- g_free(editscript);
-}
 
-static void
-action_script_callback (GtkWidget *w, DenemoDirective *directive){
-gchar *actionscript = get_action_script(directive->tag->str);
- if(actionscript)
-   call_out_to_guile(actionscript);
- else
-   g_warning("action script has vanished");
-}
 
 static void
 button_callback (GtkWidget *w, DenemoDirective *directive){
-gchar *script = get_action_script(directive->tag->str);
- if(script)
-   call_out_to_guile(script);
- else {
-   script = get_editscript_filename(directive->tag->str);
-   if(script)
-     execute_script_file(script);
-   else {
-     gpointer fn = g_object_get_data(G_OBJECT(w), "fn");
-     if(fn)
-       edit_directive_callback(w, fn);
-   }
- }
+  if(directive->override&DENEMO_OVERRIDE_EDITOR)
+    {
+      GtkWidget *texteditor = (GtkWidget*)g_object_get_data(G_OBJECT(directive->widget), DENEMO_TEXTEDITOR_TAG);
+      if(texteditor) {
+	//FIXME position at cursor if a toplevel window
+	gtk_widget_show_all(gtk_widget_get_toplevel(texteditor));
+	gtk_window_present(GTK_WINDOW(gtk_widget_get_toplevel(texteditor)));
+      }
+    } else {
+      gchar *script = get_action_script(directive->tag->str);
+      if(script)
+	call_out_to_guile(script);
+      else {
+	script = get_editscript_filename(directive->tag->str);
+	if(script)
+	  execute_script_file(script);
+	else {
+	  gpointer fn = g_object_get_data(G_OBJECT(w), "fn");
+	  if(fn)
+	    edit_directive_callback(w, fn);
+	}
+      }
+    }
 }
+
+/* return a GtkTextView which has been installed inside a scrolled window */
+static GtkWidget * create_text_window(void) {
+  GtkWidget *textview = gtk_text_view_new();
+  GtkWidget *w = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+  gtk_window_set_title (GTK_WINDOW (w), "Denemo Editor:Newline to update, Esc for Advanced Edit");
+  gtk_window_set_default_size(GTK_WINDOW (w), 200, 100);
+  gtk_window_set_position(GTK_WINDOW (w),GTK_WIN_POS_MOUSE);
+  g_signal_connect(G_OBJECT(w), "delete-event", G_CALLBACK(gtk_widget_hide_on_delete), w);
+  GtkWidget *main_vbox = gtk_vbox_new (FALSE, 1);
+  gtk_container_add (GTK_CONTAINER (w), main_vbox);
+
+  GtkWidget *sw = gtk_scrolled_window_new (NULL, NULL);
+  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
+				  GTK_POLICY_AUTOMATIC,
+				  GTK_POLICY_AUTOMATIC);
+  gtk_box_pack_start (GTK_BOX (main_vbox), sw, TRUE, TRUE, 0);
+  gtk_container_add (GTK_CONTAINER (sw), textview);
+  return textview;
+}
+
+static assign_text(GtkWidget *w, gchar *text) {
+  GtkTextBuffer *textbuffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(w));
+  if(textbuffer)
+    gtk_text_buffer_set_text(textbuffer, text, -1);
+}
+
+/* create a label. FIXME escape markup
+Use the display string up to the first newline, if it is long enough
+eles use tag
+*/
+static void
+set_directive_graphic_label(DenemoDirective *directive) {
+  gchar *value;
+  if(directive->display && directive->display->len>1)
+    value = g_strdup_printf("%s", directive->display->str);
+  else
+    value = g_strdup(directive->tag->str);
+  gchar *c;
+  for(c=value;*c;c++)
+    if(*c=='\n') {
+      *c = 0;
+      break;
+    }
+  if(GTK_IS_MENU_ITEM(directive->widget))
+    gtk_menu_item_set_label_text((GtkMenuItem*)directive->widget, value);
+  else
+    gtk_label_set_markup((GtkLabel *)gtk_bin_get_child(GTK_BIN(directive->widget)), value);
+  g_free(value);
+}
+static gboolean text_edit_directive(DenemoDirective *directive, gchar *what);
+
+static editor_keypress(GtkWidget *w, GdkEventKey *event, DenemoDirective *directive) {
+  GtkTextIter startiter, enditer;
+  GtkTextBuffer *textbuffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(w));
+  gtk_text_buffer_get_start_iter (textbuffer, &startiter);
+  gtk_text_buffer_get_end_iter (textbuffer, &enditer);
+  gchar *text = gtk_text_buffer_get_text (textbuffer, &startiter, &enditer, FALSE);
+  if(directive->display)
+    g_string_assign(directive->display, text);
+  else
+    directive->display = g_string_new(text);
+  //if the GdkEventKey is newline, run the editscript for the directive
+
+  //FIXME use switch
+  if(event->keyval==GDK_Escape)
+    if(!text_edit_directive (directive, "unknown")) {
+      /* I have used "unknown" here because we would need to get the name e.g. "score" "movementcontrol" etc from fn, but this is only used for the create a script thing...
+	 g_object_get_data(G_OBJECT(directive->widget), "fn") 
+      */
+      GList **directives_ptr = g_object_get_data(G_OBJECT(directive->widget), "directives-pointer");
+      if(directives_ptr)
+	delete_directive(g_object_get_data(G_OBJECT(directive->widget), "directives-pointer"), directive->tag->str);
+      else
+	warningdialog("Cannot delete via this mechanism, sorry");
+      return TRUE;
+    }
+  if(event->keyval==GDK_Return) {
+    gchar *filename = get_editscript_filename(directive->tag->str);
+    if(filename)
+      execute_script_file(filename);
+    set_directive_graphic_label(directive);
+  }
+  return TRUE;
+}
+static void
+attach_textedit_widget(DenemoDirective *directive) {
+  if(directive->override&DENEMO_OVERRIDE_EDITOR){
+    GtkWidget *texteditor = create_text_window();
+    //    g_signal_connect (G_OBJECT (texteditor), "key-press-event",
+    //		      G_CALLBACK (editor_keypress), directive);
+    g_signal_connect_after (G_OBJECT (texteditor), "key-release-event",
+		      G_CALLBACK (editor_keypress), directive);
+    if(directive->display==NULL)
+      directive->display = g_string_new("");
+    assign_text(texteditor, directive->display->str);
+    // g_object_set_data(texteditor, "gstring", directive->display);
+    g_object_set_data(G_OBJECT(directive->widget), DENEMO_TEXTEDITOR_TAG, texteditor);
+  }
+}
+
 /*
   widget_for_directive()
-  if directive does not have graphic:
-     fn gives the type of directive, which must be a non-DenemoObject directive: it determines where the widget goes (score or movement level, DenemoGUI or DenemoScore respectively, or in staff or voice menu)
-     
-     creates a widget (button or menu depending on fn) for editing/actioning directive, point directive->graphic to it and attach a callback to edit/action this directive, passing fn as data to it (to say what sort of directive it is) or the directive itself (for actionscripts/editscripts).
-   places the widget in the appropriate buttonbox.
+  if directive does not have widget:
 
-     set  the label for the widget from directive->graphic_name directive->display
+     creates a widget (button or menu depending on fn) for editing/actioning directive, point directive->widget to it and attach a callback to edit/action this directive, passing fn as data to it (to say what sort of directive it is) or the directive itself (for actionscripts/editscripts).
+
+if directive is non-DenemoObject directive it  places the widget in the appropriate buttonbox/menu, the directives attached to DenemoObjects have menus created dynamically. (fn gives the type of directive: it determines where the widget goes (score or movement level, DenemoGUI or DenemoScore respectively, or in staff or voice menu))
+
+     set  the label for the widget from directive->display or the tag if no display text
      set  the visibility for the widget from directive->override
-
 */
      
 void 
 widget_for_directive(DenemoDirective *directive,  void fn()) {
   GtkWidget *box;
-  gchar *value = directive->display?directive->display->str:"";
-  if((directive->graphic==NULL) ) {
+  gchar *value = "";
+  //FIXME we don't need value now...
+  if (directive->override&DENEMO_OVERRIDE_EDITOR) {
+      value = directive->tag->str;
+  } else
+    if(directive->display) 
+      value = directive->display->str;
+
+  if((directive->widget==NULL) ) {
     if(fn==(void(*)())score_directive_put_graphic ||fn==(void(*)())scoreheader_directive_put_graphic ||fn==(void(*)())paper_directive_put_graphic)  
       box = Denemo.gui->buttonbox;
     else
-      box = Denemo.gui->si->buttonbox;
+      if(fn==(void(*)())movementcontrol_directive_put_graphic  ||fn==(void(*)())header_directive_put_graphic )
+	box = Denemo.gui->si->buttonbox;
+      else
+	box = NULL;
+
+
     if(fn==(void(*)())staff_directive_put_graphic) {
       //g_print("Doing the staff case");
-      directive->graphic = (gpointer)gtk_menu_item_new_with_label(value);
       /* g_print("directive-type %s.....", thetype);	*/
       GtkWidget *menu;
       menu = (GtkWidget *)((DenemoStaff*)Denemo.gui->si->currentstaff->data)->staffmenu;
-      g_signal_connect(G_OBJECT(directive->graphic), "activate",  G_CALLBACK(edit_directive_callback), fn);
-      gtk_menu_shell_append(GTK_MENU_SHELL(menu), directive->graphic);
+      directive->widget = gtk_menu_item_new_with_label(value);
+      attach_textedit_widget(directive);
+      g_signal_connect(G_OBJECT(directive->widget), "activate",  G_CALLBACK(button_callback), directive);
+      gtk_menu_shell_prepend(GTK_MENU_SHELL(menu), GTK_WIDGET(directive->widget));
     } else    
       if(fn==(void(*)())voice_directive_put_graphic) {
 	//g_print("Doing the voice case");
-	directive->graphic = gtk_menu_item_new_with_label(value);//WARNING _with_label is important
-	/* g_print("directive-type %s.....", thetype);	*/
+	directive->widget = GTK_WIDGET(gtk_menu_item_new_with_label(value));//WARNING _with_label is important
+	attach_textedit_widget(directive);
 	GtkWidget *menu;
 	menu = (GtkWidget *)((DenemoStaff*)Denemo.gui->si->currentstaff->data)->voicemenu;  
-	g_signal_connect(G_OBJECT(directive->graphic), "activate",  G_CALLBACK(edit_directive_callback), fn);
-	gtk_menu_shell_append(GTK_MENU_SHELL(menu), directive->graphic);
-      }  else {
-	//g_print("Doing the non-staff case");
-	//DISTINGUISH TWO CASES HERE if there is an editscript for directive->tag then use that for the callback and if there is a graphic with name directive->graphic_name then use that as an icon for the button widget coming next.
-	gchar *editscript = get_editscript_filename(directive->tag->str);
-	//FIXME look for a graphic of graphic_name & place it on button as icon ...
-     
-	directive->graphic = gtk_button_new_with_label(value);
-	{
-	  GtkWidget *label = gtk_bin_get_child(directive->graphic);
-	  //g_print("%s%s\n","type is", label?g_type_name(G_TYPE_FROM_INSTANCE(label)):"NULL widget");
-	  gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+	g_signal_connect(G_OBJECT(directive->widget), "activate",  G_CALLBACK(button_callback), fn);
+	gtk_menu_shell_append(GTK_MENU_SHELL(menu), GTK_WIDGET(directive->widget));
+      }  else 
+	if(box)  {
+	  //g_print("Doing the score and movement cases");
+	  directive->widget = GTK_WIDGET(gtk_button_new_with_label(value));
+	  {
+	    GtkWidget *label = gtk_bin_get_child(GTK_BIN(directive->widget));
+	    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+	  }
+	  attach_textedit_widget(directive);
+	  g_signal_connect(G_OBJECT(directive->widget), "clicked",  G_CALLBACK(button_callback), directive);
+	  if(box){
+	    gtk_box_pack_start (GTK_BOX (box), GTK_WIDGET(directive->widget), FALSE, TRUE,0);
+	    gtk_widget_show(box);
+	  }
+	} else {
+	  directive->widget = gtk_menu_item_new_with_label(value);
+	  attach_textedit_widget(directive);
+	  g_signal_connect(G_OBJECT(directive->widget), "activate",  G_CALLBACK(button_callback), directive);
 	}
-#if 0
-	{
-	  GtkImage *image = gtk_image_new_from_pixbuf(pixbuf);
-	  gtk_button_set_image(button, image);
-	}
-#endif
+    g_object_set_data(G_OBJECT(directive->widget), "directive", (gpointer)directive);
+    g_object_set_data(G_OBJECT(directive->widget), "fn", (gpointer)fn);
+    GTK_WIDGET_UNSET_FLAGS(directive->widget, GTK_CAN_FOCUS);
+  }//end of no widget
 
-#if 1
-	g_object_set_data(G_OBJECT(directive->graphic), "fn", (gpointer)fn);
-	g_signal_connect(G_OBJECT(directive->graphic), "clicked",  G_CALLBACK(button_callback), directive);
-#else
-	gchar *actionscript = get_action_script(directive->tag->str);
-	if(actionscript)
-	  g_signal_connect(G_OBJECT(directive->graphic), "clicked",  G_CALLBACK(action_script_callback), directive); else	
-	    if(editscript) 
-	      g_signal_connect(G_OBJECT(directive->graphic), "clicked",  G_CALLBACK(runscript_callback), directive);
-	    else
-	      g_signal_connect(G_OBJECT(directive->graphic), "clicked",  G_CALLBACK(edit_directive_callback), fn);
-#endif
-	g_free(editscript);
-	gtk_box_pack_start (GTK_BOX (box), directive->graphic, FALSE, TRUE,0);
-	g_object_set_data(directive->graphic, "directive", (gpointer)directive);
-	gtk_widget_show(box);
-      }
-    GTK_WIDGET_UNSET_FLAGS(directive->graphic, GTK_CAN_FOCUS);
-  }//no graphic
-  (directive->override&DENEMO_OVERRIDE_GRAPHIC)?gtk_widget_show(directive->graphic):gtk_widget_hide(directive->graphic);
-  if(GTK_IS_MENU_ITEM(directive->graphic))
-    gtk_menu_item_set_label_text(directive->graphic, value);
-  else
-    gtk_label_set_markup((GtkLabel *)gtk_bin_get_child(GTK_BIN(directive->graphic)), value);
+  (directive->override&DENEMO_OVERRIDE_GRAPHIC)?gtk_widget_show(GTK_WIDGET(directive->widget)):gtk_widget_hide(GTK_WIDGET(directive->widget));
+
+  // here handle the case where widget has a GtkTextView editing the text in value
+  if(directive->display) { 
+    GtkWidget *texteditor =  (GtkWidget*)g_object_get_data(G_OBJECT(directive->widget), DENEMO_TEXTEDITOR_TAG);
+    if(texteditor)
+      assign_text(texteditor, directive->display->str);
+  }
+  set_directive_graphic_label(directive);
 }
 
 
 // create a directive for non-DenemoObject directive #what
-// create a button to edit/action the directive as the directive->graphic
-#define PUT_GRAPHIC_WIDGET_STR(field, what, directives_name) gpointer \
-what##_directive_put_##field(gchar *tag, gchar *value) {\
-  what *current = get_##what();\
-  if(current==NULL) return NULL;\
-  if(current->directives_name==NULL)\
-       create_directives (&current->directives_name, tag);\
-  DenemoDirective *directive = get_##what##_directive(tag);\
-  if(directive==NULL){\
-    directive=new_directive(tag);\
-    current->directives_name = g_list_append(current->directives_name, directive);\
-    }\
-  if(directive->field==NULL) \
-    directive->field = g_string_new(value);\
-  else\
-    g_string_assign(directive->field, value);\
-  widget_for_directive(directive, (void(*)())what##_directive_put_graphic);\
-  return (gpointer)directive;\
-}
+// assigning the string VALUE to the field ##field
+// also create a button or menuitem ( if it does not already exist) as the directive->widget, this will be used to edit/action the directive
+// Compare this with the macros above which create the what##_directive_put_##field() without calling widget_for_directive() and so do not create a widget in the graphic field, except via the user setting graphic_name.
 
-#define PUT_GRAPHIC_WIDGET_INT(field, what, directives_name)\
-gboolean \
-what##_directive_put_##field(gchar *tag, gint value) {\
-  what *current = get_##what();\
-  if(current==NULL) return FALSE;\
-  if(current->directives_name==NULL)\
-       create_directives (&current->directives_name, tag);\
-  DenemoDirective *directive = get_##what##_directive(tag);\
-  if(directive==NULL){\
-    directive=new_directive(tag);\
-    current->directives_name = g_list_append(current->directives_name, directive);\
-    }\
- directive->field = value;\
- widget_for_directive(directive, (void(*)())what##_directive_put_graphic);\
- return TRUE;\
-}
+#define PUT_GRAPHIC_WIDGET_STR(field, what, directives_name) PUT_STR_FIELD_FUNC_NAME(what, field, directives_name)
+#define PUT_GRAPHIC_WIDGET_INT(field, what, directives_name) PUT_INT_FIELD_FUNC_NAME(what, field, directives_name)
 
-//FIXME this is just storing the graphic name, it can be placed on the button/menu item as an icon
-#define PUT_GRAPHIC_WIDGET_GRAPHIC(what, directives_name) gpointer \
+
+//As the above (for string and int) but for the graphic name field
+//FIXME this is just storing the graphic name, any bitmap of that name could be placed on the button/menu item as an icon
+#define PUT_GRAPHIC_WIDGET_GRAPHIC(what, name) gpointer \
 what##_directive_put_graphic(gchar *tag, gchar *value) {\
   what *current = get_##what();\
   if(current==NULL) return NULL;\
-  if(current->directives_name==NULL)\
-       create_directives (&current->directives_name, tag);\
+  if(current->name==NULL)\
+       create_directives (&current->name, tag);\
   DenemoDirective *directive = get_##what##_directive(tag);\
   if(directive==NULL){\
     directive=new_directive(tag);\
-    current->directives_name = g_list_append(current->directives_name, directive);\
+    current->name = g_list_append(current->name, directive);\
     }\
   if(directive->graphic_name==NULL) \
     directive->graphic_name = g_string_new(value);\
   else\
     g_string_assign(directive->graphic_name, value);\
   widget_for_directive(directive, (void(*)())what##_directive_put_graphic);\
+  g_object_set_data(G_OBJECT(directive->widget), "directives-pointer", &current->name);\
   return (gpointer)directive;\
 }
 
@@ -1594,7 +1677,7 @@ DenemoDirective *select_directive(gchar *instr, GList *directives) {
   }
   gtk_widget_destroy (dialog);
   if(response && response->tag)
-    g_print("Came back with response %s\n", response->tag->str);
+    ;//g_print("Came back with response %s\n", response->tag->str);
   return response;
 }
 
@@ -1659,7 +1742,37 @@ void user_select_directive_at_cursor(gchar **what, GList ***pdirectives, DenemoD
 }
 
 
+static void populate_menu_for_directive(GtkWidget *menu, DenemoDirective *directive) {
+  if(directive->widget) {
+  if(!gtk_widget_get_parent(directive->widget))
+      gtk_menu_shell_prepend(GTK_MENU_SHELL(menu), GTK_WIDGET(directive->widget));
+  //g_print("now add %p\n", directive->widget);
+    gtk_widget_show(directive->widget);
+  }
+}
+static void populate_menu_for_directives(GtkWidget *menu, GList *directives) {
+  g_object_set_data(G_OBJECT(menu), "directives", directives);
+  //g_print("setting directives %p for menu %p\n", directives, menu);
+  for(;directives;directives=directives->next) {
+    populate_menu_for_directive(menu, directives->data);
+  }
+}
 
+/* callback for deactivate signal installed at startup on the NoteEditPopup menu
+   it removes the menu items for the specific note 
+ */
+gboolean unpopulate_menu(GtkWidget *menu) {
+  GList *directives = g_object_get_data(G_OBJECT(menu), "directives");
+  //g_print("removing directives %p for menu %p\n", directives, menu);
+  for(;directives;directives=directives->next) {
+    DenemoDirective *directive = directives->data;
+    //g_print("now remove %p\n", directive->widget);
+    if(directive->widget)
+      gtk_container_remove(GTK_CONTAINER(menu), directive->widget);
+  }
+  g_object_set_data(G_OBJECT(menu), "directives", NULL);
+  return FALSE;
+}
 
 
 void edit_object(GtkAction *action,  DenemoScriptParam *param) {
@@ -1689,6 +1802,12 @@ void edit_object(GtkAction *action,  DenemoScriptParam *param) {
      return;
   case CHORD:
     {
+      GList *directives =  ((chord *)obj->object)->directives;
+      note *curnote = findnote(obj, Denemo.gui->si->cursor_y); 
+      if(curnote && (curnote->mid_c_offset == Denemo.gui->si->cursor_y))
+	directives = curnote->directives;
+      GtkWidget *menu = gtk_ui_manager_get_widget (Denemo.ui_manager, "/NoteEditPopup"); 
+      populate_menu_for_directives(menu, directives);
       popup_menu( "/NoteEditPopup");
     }
     return;
@@ -1758,7 +1877,7 @@ ADD_INTTEXT(gy);
 #undef ADD_INTTEXT
  g_string_append(scheme,  "(d-RefreshDisplay)\n;;;End of scheme script");
  // quote_scheme(scheme);
- g_print("Scheme is %s\n", scheme->str);
+ //g_print("Scheme is %s\n", scheme->str);
   appendSchemeText(scheme->str);
   g_string_free(scheme, TRUE);
 }
@@ -1777,7 +1896,7 @@ static void upload_edit_script_cb (GtkWidget *widget, gchar *tag) {
   }
 }
 
-/* callback to get an edit script of name tag */
+/* callback to get an edit script of name tag into the Scheme Script window */
 static void get_edit_script (GtkWidget *widget, gchar *tag) {
   gchar *filename = get_editscript_filename(tag);
   if(filename){
@@ -1795,7 +1914,8 @@ static void get_edit_script (GtkWidget *widget, gchar *tag) {
 
 /* callback to save the scheme script text buffer as an edit script of name tag in the user's local denemo directory */
 static void put_edit_script (GtkWidget *widget, gchar *tag) {
-  gchar *filename = g_build_filename(locatedotdenemo(), "actions", "editscripts", tag, NULL);
+  gchar *tagscm = g_strconcat(tag, ".scm", NULL);
+  gchar *filename = g_build_filename(locatedotdenemo(), "actions", "editscripts", tagscm, NULL);
   if((!g_file_test(filename, G_FILE_TEST_EXISTS)) ||
      confirm("There is already an edit script for this tag", "Do you want to replace it?")){
     gchar *scheme = (gchar*)getSchemeText();
@@ -1809,6 +1929,8 @@ static void put_edit_script (GtkWidget *widget, gchar *tag) {
       g_free(scheme);
     }
   }
+  g_free(tagscm);
+  g_free(filename);
 }
 
 
@@ -1820,6 +1942,7 @@ static gboolean text_edit_directive(DenemoDirective *directive, gchar *what) {
   gboolean ret = TRUE;
 #define CREATE_SCRIPT (2)
   DenemoDirective *clone = clone_directive(directive);//for reset
+ 
   GtkWidget *dialog = gtk_dialog_new_with_buttons ("Primitive Denemo Directive Edit",
                                         GTK_WINDOW (Denemo.window),
                                         (GtkDialogFlags) (GTK_DIALOG_MODAL |
@@ -1913,19 +2036,21 @@ static gboolean text_edit_directive(DenemoDirective *directive, gchar *what) {
 
   gtk_widget_show_all (dialog);
   gint response = gtk_dialog_run (GTK_DIALOG (dialog));
-  g_print("Got response %d\n", response);
+  // g_print("Got response %d\n", response);
 
 
   if (response == GTK_RESPONSE_CANCEL || response == GTK_RESPONSE_DELETE_EVENT || response ==  GTK_RESPONSE_REJECT){
-    directive->graphic = NULL;//prevent any button being destroyed
+    GtkWidget *ref_widget = directive->widget;//not cloned
+    directive->widget = NULL;//prevent any button being destroyed
     free_directive_data(directive);
     memcpy(directive, clone, sizeof(DenemoDirective));
+    directive->widget = ref_widget;
     if (response ==  GTK_RESPONSE_REJECT) {
       ret = FALSE;//that is it may be deleted, we ensure it has not been changed first,as the tag is used for delelet
     }
   }
   else {
-    clone->graphic = NULL;//prevent any button being destroyed
+    clone->widget = NULL;//prevent any button being destroyed FIXME ???
     free_directive(clone);
   }
 #define REMOVEEMPTIES(field)\
@@ -1940,10 +2065,11 @@ if(directive->field && directive->field->len==0) g_string_free(directive->field,
   
   if(directive->tag && directive->tag->len==0)
     directive->tag = g_string_new(UNKNOWN_TAG);
+  if(directive->widget){
+    if(GTK_IS_WIDGET(directive->widget))
+      widget_for_directive(directive, NULL/* no need to pass fn in as it is only needed if there is not widget, g_object_get_data(directive->widget, "fn") */);
+  }
   if(directive->graphic){
-    if(GTK_IS_WIDGET(directive->graphic))
-      widget_for_directive(directive, NULL);
-    else
       loadGraphicItem (directive->graphic_name->str,  (GdkBitmap **)&directive->graphic,  &directive->width, &directive->height);
   }
   gtk_widget_destroy (dialog);
@@ -1974,36 +2100,6 @@ edit_directive(DenemoDirective *directive, gchar *what) {
 
 static void edit_directive_callback(GtkWidget *w, gpointer what) {
   DenemoDirective *directive = g_object_get_data(G_OBJECT(w), "directive");
-
-#if 0
-  if(!edit_directive(directive, what)){
-    if(what == score_directive_put_graphic)
-      delete_score_directive(directive->tag->str);
-    else
-      if(what == staff_directive_put_graphic)
-	delete_staff_directive(directive->tag->str);
-      else
-	if(what == voice_directive_put_graphic)
-	  delete_voice_directive(directive->tag->str);
-	else
-	  if(what == scoreheader_directive_put_graphic)
-	    delete_scoreheader_directive(directive->tag->str);
-	  else
-	  if(what == header_directive_put_graphic)
-	    delete_header_directive(directive->tag->str);
-	  else
-	  if(what == paper_directive_put_graphic)
-	    delete_paper_directive(directive->tag->str);
-	  else
-	  if(what == layout_directive_put_graphic)
-	    delete_layout_directive(directive->tag->str);
-	  else
-	  if(what == movementcontrol_directive_put_graphic)
-	    delete_movementcontrol_directive(directive->tag->str);
-	  else
-	    g_warning("Not implemented");
-  }
-#else
 #define DO_TYPE(score)\
     if(what == score##_directive_put_graphic){\
       if(!edit_directive(directive, #score))\
@@ -2018,13 +2114,10 @@ static void edit_directive_callback(GtkWidget *w, gpointer what) {
     DO_TYPE(paper);
     DO_TYPE(layout);
     DO_TYPE(movementcontrol);
-#undef DO_TYPE
-#endif
-
-
-
-  
- }
+    DO_TYPE(chord);
+    DO_TYPE(note);
+#undef DO_TYPE 
+}
 
 
 /**
@@ -2045,8 +2138,7 @@ void edit_object_directive(GtkAction *action,  DenemoScriptParam *param) {
     directive->tag = g_string_new(UNKNOWN_TAG);
   if(!edit_directive(directive, what)) {
     if(directives && *directives) {
-      *directives = g_list_remove(*directives, directive);
-      free_directive(directive);
+      delete_directive(directives, directive->tag->str);
     } else {//standalone directive
       dnm_deleteobject(Denemo.gui->si);
     }
@@ -2405,7 +2497,7 @@ GET_INT_FIELD_FUNC(keysig, override)
 GET_INT_FIELD_FUNC(keysig, width)
 GET_INT_FIELD_FUNC(keysig, height)
 
-PUT_GRAPHIC(keysig)
+
 
 PUT_STR_FIELD_FUNC(keysig, prefix)
 PUT_STR_FIELD_FUNC(keysig, postfix)
@@ -2432,8 +2524,6 @@ GET_INT_FIELD_FUNC(timesig, override)
 GET_INT_FIELD_FUNC(timesig, width)
 GET_INT_FIELD_FUNC(timesig, height)
 
-PUT_GRAPHIC(timesig)
-
 PUT_STR_FIELD_FUNC(timesig, prefix)
 PUT_STR_FIELD_FUNC(timesig, postfix)
 PUT_STR_FIELD_FUNC(timesig, display)
