@@ -144,17 +144,12 @@ void playpitch(double pitch, double duration, double volume, int channel) {
 
 void play_midikey(gint key, double duration, double volume, gint channel){
 #ifdef _HAVE_JACK_
-  playpitch(midi2hz(key), duration, volume, channel);
-
-/* FIXME replace this with something direct based on */
-/*  buffer = jack_midi_event_reserve(port_buf, i, 3); */
-/*                                 buffer[2] = 64;         /\* velocity *\/ */
-/*                                 buffer[1] = note_frqs[j]; */
-/*                                 buffer[0] = 0x90;       /\* note on *\/ */
-/*  and a timer to turn the note off after duration */
+  //playpitch(midi2hz(key), duration, volume, channel);	
+#define NOTEDURATION 1000 /*duration in mseconds*/ 
+  jack_playpitch(key, NOTEDURATION);
 
 #else
- playpitch(midi2hz(key), duration, volume, channel);
+  playpitch(midi2hz(key), duration, volume, channel);
 #endif
 }
 
