@@ -12,6 +12,10 @@
 #include "selectops.h"
 #include "lilydirectives.h"
 #include "mousing.h"
+
+
+static gboolean lh_down;
+
 /**
  * Get the mid_c_offset of an object or click from its height relative
  * to the top of the staff.  
@@ -145,7 +149,7 @@ static gint staff_at (gint y, DenemoScore *si) {
   ret = count+si->top_staff-1;
   if(ret==primary_staff(si))
     ret = si->currentstaffnum;
-  return ret;
+  return ret>0?ret:1;
 }
 
 /**
@@ -200,6 +204,8 @@ get_placement_from_coordinates (struct placement_info *pi,
 		     closer to current.
 
 		     Do the math - it really does work out.  */
+
+		  //???modify current->x by gx where graphic_override is set????
 		  if (x_to_explain - (current->x + current->minpixelsalloted)
 		      < next->x - x_to_explain)
 		    {
@@ -240,7 +246,7 @@ set_cursor_for(guint state) {
   if(cursor)
     gdk_window_set_cursor(Denemo.window->window, cursor);
    else 
-    gdk_window_set_cursor(Denemo.window->window, gdk_cursor_new(GDK_RIGHT_PTR));//FIXME? does this take time/hog memory
+     gdk_window_set_cursor(Denemo.window->window, gdk_cursor_new(GDK_LEFT_PTR));//FIXME? does this take time/hog memory
 }
 
 
@@ -322,6 +328,8 @@ static change_staff(DenemoScore *si, gint num, GList *staff) {
   show_lyrics();
   return TRUE;
 }
+
+
 /**
  * Mouse motion callback 
  *
@@ -331,7 +339,8 @@ scorearea_motion_notify (GtkWidget * widget, GdkEventButton * event)
 {
   DenemoGUI *gui = Denemo.gui;
   //  g_print("Marked %d\n", gui->si->markstaffnum);
-    if (selecting && gui->si->markstaffnum){
+
+    if (lh_down || (selecting && gui->si->markstaffnum)){
       struct placement_info pi; 
       if (event->y < 0)
 	get_placement_from_coordinates (&pi, event->x, 0, gui->si);
@@ -351,6 +360,10 @@ scorearea_motion_notify (GtkWidget * widget, GdkEventButton * event)
 	   (gint) (g_list_length ((objnode *) gui->si->currentmeasure->data)));
 	
 	set_cursor_y_from_click (gui, event->y);
+	if(lh_down & !selecting){
+	  set_mark(gui);
+	  selecting=TRUE;
+	}
 	calcmarkboundaries (gui->si);
 	if(event->state&(GDK_BUTTON1_MASK|GDK_BUTTON2_MASK|GDK_BUTTON3_MASK))
 	   perform_command(event->state, GESTURE_MOVE, event->state&GDK_BUTTON1_MASK);
@@ -374,11 +387,11 @@ DenemoGUI *gui = Denemo.gui;
   struct placement_info pi;
   gboolean left = (event->button != 3);
   gtk_widget_grab_focus(widget);
-  if(gui->si->top_staff==1 && 
-     event->y < ((DenemoStaff *) gui->si->thescore->data)->space_above) {
-    popup_menu("/ScorePopup");
-    return TRUE;
-  }
+  //  if(gui->si->top_staff==1 && 
+  //    event->y < ((DenemoStaff *) gui->si->thescore->data)->space_above) {
+  //   popup_menu("/ScorePopup");
+  //   return TRUE;
+  //  }
   gint key = gui->si->maxkeywidth;
   gint cmajor = key?0:5;//allow some area for keysig in C-major
   if(left && (gui->si->leftmeasurenum>1) && (event->x<KEY_MARGIN+SPACE_FOR_TIME+key)  && (event->x>LEFT_MARGIN)){
@@ -418,6 +431,8 @@ DenemoGUI *gui = Denemo.gui;
       return TRUE;
     }
   }
+
+
   if (pi.the_measure != NULL){ /*don't place cursor in a place that is not there*/
     //gui->si->currentstaffnum = pi.staff_number;
     //gui->si->currentstaff = pi.the_staff;
@@ -432,20 +447,24 @@ DenemoGUI *gui = Denemo.gui;
     set_cursor_y_from_click (gui, event->y);
     if(pi.nextmeasure)
       measureright(NULL);
-    {static gboolean alternate = TRUE;
-    if(alternate && left){
-      set_mark(gui);
-      selecting = TRUE;
-    } else
-      gui->si->markstaffnum = 0;
-    alternate = !alternate;
-    }
-    write_status(gui);
-    /* Redraw to show new cursor position, note a real draw is needed because of side effects on display*/
-    gtk_widget_draw (gui->scorearea, NULL);
 
-    //g_signal_handlers_unblock_by_func(gui->scorearea, G_CALLBACK (scorearea_motion_notify), gui);   
+    write_status(gui);
+
+
   }
+
+
+  if(left) {
+    // if(!(GDK_CONTROL_MASK&event->state))
+      gui->si->markstaffnum = 0;
+    //    else
+    //  calcmarkboundaries (gui->si);
+     lh_down = TRUE;
+ 
+  }
+  /* Redraw to show new cursor position, note a real draw is needed because of side effects on display*/
+  gtk_widget_draw (gui->scorearea, NULL);
+    
   set_cursor_for(event->state | (left?GDK_BUTTON1_MASK:GDK_BUTTON3_MASK));
   perform_command(event->state | (left?GDK_BUTTON1_MASK:GDK_BUTTON3_MASK), GESTURE_PRESS, left);
   
@@ -463,6 +482,8 @@ scorearea_button_release (GtkWidget * widget, GdkEventButton * event)
 DenemoGUI *gui = Denemo.gui;
  gboolean left = (event->button != 3);
  //g_signal_handlers_block_by_func(gui->scorearea, G_CALLBACK (scorearea_motion_notify), gui); 
+ if(left)
+   lh_down = FALSE;
  selecting = FALSE;
  set_cursor_for(event->state&DENEMO_MODIFIER_MASK);
  perform_command(event->state, GESTURE_RELEASE, left);
