@@ -84,15 +84,15 @@ set_preferences (struct callbackdata *cbdata)
 
 
 void
-playback_properties_change (GtkAction * action, DenemoGUI * gui)
+playback_properties_change (GtkAction *action, gpointer param)
 {
-
+  DenemoGUI *gui = Denemo.gui;
   GtkWidget *dialog;
   GtkWidget *label;
   GtkWidget *table;
   GtkWidget *hbox;
   GtkWidget *tempo;
-  GtkWidget *play_entire_pice;
+  GtkWidget *play_entire_piece;
   GtkWidget *play_measure;
   GtkWidget *from_measure;
   GtkWidget *to_measure;
@@ -114,7 +114,7 @@ playback_properties_change (GtkAction * action, DenemoGUI * gui)
   static struct cs_callback csdata;	/* for csound file selection */
 
   dialog = gtk_dialog_new_with_buttons (_("Playback properties"),
-					GTK_WINDOW (gui->window),
+					GTK_WINDOW (Denemo.window),
 					(GtkDialogFlags) (GTK_DIALOG_MODAL |
 							  GTK_DIALOG_DESTROY_WITH_PARENT),
 					GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
@@ -181,9 +181,9 @@ playback_properties_change (GtkAction * action, DenemoGUI * gui)
   gtk_widget_set_size_request (label, 12, -1);
 
 
-  play_entire_pice =
-    gtk_radio_button_new_with_label (NULL, _("Play the entire piece"));
-  gtk_table_attach (GTK_TABLE (table), play_entire_pice, 1, 2, 3, 4,
+  play_entire_piece =
+    gtk_radio_button_new_with_label (NULL, _("Play from cursor to end"));
+  gtk_table_attach (GTK_TABLE (table), play_entire_piece, 1, 2, 3, 4,
 		    (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0,
 		    0);
 
@@ -201,7 +201,7 @@ playback_properties_change (GtkAction * action, DenemoGUI * gui)
 
   play_measure =
     gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON
-						 (play_entire_pice),
+						 (play_entire_piece),
 						 _("Play measure"));
   gtk_box_pack_start (GTK_BOX (hbox), play_measure, FALSE, FALSE, 0);
 
@@ -225,7 +225,7 @@ playback_properties_change (GtkAction * action, DenemoGUI * gui)
 
   if (gui->si->start == 0)
     {
-      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (play_entire_pice),
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (play_entire_piece),
 				    TRUE);
       gtk_widget_set_sensitive (from_measure, FALSE);
       gtk_widget_set_sensitive (to_measure, FALSE);
@@ -343,7 +343,7 @@ playback_properties_change (GtkAction * action, DenemoGUI * gui)
 		    (GtkAttachOptions) (0), 0, 0);
   csoundcommand = gtk_entry_new ();
   gtk_entry_set_text (GTK_ENTRY (csoundcommand),
-		      gui->prefs->csoundcommand->str);
+		      Denemo.prefs.csoundcommand->str);
   gtk_table_attach (GTK_TABLE (table), csoundcommand, 1, 2, 0, 1,
 		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
@@ -353,8 +353,8 @@ playback_properties_change (GtkAction * action, DenemoGUI * gui)
 		    (GtkAttachOptions) (GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
   orcfile = gtk_entry_new ();
-  if (gui->prefs->csoundorcfile)
-    gtk_entry_set_text (GTK_ENTRY (orcfile), gui->prefs->csoundorcfile->str);
+  if (Denemo.prefs.csoundorcfile)
+    gtk_entry_set_text (GTK_ENTRY (orcfile), Denemo.prefs.csoundorcfile->str);
   gtk_table_attach (GTK_TABLE (table), orcfile, 1, 2, 1, 2,
 		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
@@ -378,7 +378,7 @@ playback_properties_change (GtkAction * action, DenemoGUI * gui)
   gtk_widget_show (label);
 
   rtcs = gtk_check_button_new ();
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (rtcs), gui->prefs->rtcs);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (rtcs), Denemo.prefs.rtcs);
   gtk_table_attach (GTK_TABLE (table), rtcs, 1, 2, 3, 4,
 		    (GtkAttachOptions) (GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
@@ -404,7 +404,7 @@ playback_properties_change (GtkAction * action, DenemoGUI * gui)
 
   midiplayerentry = gtk_entry_new ();
   gtk_entry_set_text (GTK_ENTRY (midiplayerentry),
-		      gui->prefs->midiplayer->str);
+		      Denemo.prefs.midiplayer->str);
   gtk_table_attach (GTK_TABLE (table), midiplayerentry, 1, 2, 1, 2,
 		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
@@ -417,7 +417,7 @@ playback_properties_change (GtkAction * action, DenemoGUI * gui)
 
   audioplayerentry = gtk_entry_new ();
   gtk_entry_set_text (GTK_ENTRY (audioplayerentry),
-		      gui->prefs->audioplayer->str);
+		      Denemo.prefs.audioplayer->str);
   gtk_table_attach (GTK_TABLE (table), audioplayerentry, 1, 2, 2, 3,
 		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
@@ -425,7 +425,7 @@ playback_properties_change (GtkAction * action, DenemoGUI * gui)
   gtk_widget_show_all (dialog);
 
   /* Set up the callback data */
-  cbdata.prefs = gui->prefs;
+  cbdata.prefs = &Denemo.prefs;
   cbdata.midiplayerentry = midiplayerentry;
   cbdata.audioplayerentry = audioplayerentry;
   cbdata.csoundcommand = csoundcommand;
