@@ -12,6 +12,7 @@
 #include <errno.h>
 #include <fcntl.h>
 #include <unistd.h>
+#include <string.h>
 #include "config.h"
 #include <denemo/denemo.h>
 #include <libxml/parser.h>
@@ -20,7 +21,7 @@
 #include "prefops.h"
 
 static gint
-readxmlprefs (gchar * filename, DenemoPrefs * prefs);
+readxmlprefsFile (gchar * filename);
 
 /**
  * This checks to see if there's a .denemo/ directory in the user's
@@ -65,8 +66,8 @@ void
 initprefs ()
 {
   gchar *systemwide = g_build_filename (get_conf_dir (), "denemo.conf", NULL);
-  DenemoPrefs *ret = &Denemo.prefs;
-  gchar * dotdenemo = locatedotdenemo ();
+  #define ret (&Denemo.prefs)
+  gchar * dotdenemo = (gchar*)locatedotdenemo ();
   gchar *localrc = dotdenemo?g_build_filename (dotdenemo, "denemorc", NULL):NULL;
 
   /* Reasonable default values */
@@ -129,19 +130,20 @@ initprefs ()
 
   /* Read values from systemwide preferences file */
 
-  readxmlprefs (systemwide, ret);
+  readxmlprefsFile (systemwide);
 
   /* Read values from personal preferences file */
 
   //readpreffile (localrc, ret);
   if(localrc) {
     if(g_file_test(localrc,  G_FILE_TEST_EXISTS))
-      readxmlprefs (localrc, ret);
+      readxmlprefsFile (localrc);
     else
       writeXMLPrefs(ret);
   }
   g_free (systemwide);
   g_free (localrc);
+#undef ret
 }
 
 
@@ -169,6 +171,7 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
 	  xmlChar *tmp = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);\
 	  if(tmp)\
 	    {\
+              define_scheme_variable("DenemoPref_" #field, tmp, NULL);\
 	      prefs->field =\
 		g_string_assign (prefs->field, (gchar *) tmp);\
 	      xmlFree (tmp);\
@@ -182,16 +185,20 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
 	  xmlChar *tmp = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);\
 	  if(tmp)\
 	    {\
+              define_scheme_variable("DenemoPref_" #field, tmp, NULL);\
 	      prefs->field = atoi ((gchar *) tmp);\
 	      xmlFree (tmp);\
 	    }\
 	}\
 
-      if (0 == xmlStrcmp (cur->name, (const xmlChar *) "lilypondpath"))
+      if (0 == xmlStrcmp (cur->name, (const xmlChar *) "lilypath"))
 	{
 	  xmlChar *tmp = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);
 	  if(tmp)
 	    {
+	      gchar *curname = g_strdup_printf("DenemoPref_%s", cur->name);
+	      define_scheme_variable(curname, tmp, NULL); 
+	      g_free(curname);
 	      prefs->lilypath = 
 		g_string_assign (prefs->lilypath, (gchar *) tmp);
 	      //g_print ("Lilypond Path %s\n", tmp);
@@ -207,6 +214,9 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
 	  xmlChar *tmp = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);
 	  if(tmp)
 	    {
+	      gchar *curname = g_strdup_printf("DenemoPref_%s", cur->name);
+	      define_scheme_variable(curname, tmp, NULL); 
+	      g_free(curname);
 	      prefs->autosave_timeout = atoi ((gchar *) tmp);
 	      if(prefs->autosave_timeout <1) prefs->autosave_timeout = 1;
 	      //g_print ("Autosave Timeout %s\n", tmp);
@@ -219,6 +229,9 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
 	  xmlChar *tmp = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);
 	  if(tmp)
 	    {
+	      gchar *curname = g_strdup_printf("DenemoPref_%s", cur->name);
+	      define_scheme_variable(curname, tmp, NULL); 
+	      g_free(curname);
 	      prefs->maxhistory = atoi ((gchar *) tmp);
 	      if(prefs->maxhistory <1) prefs->maxhistory = 1;
 	      xmlFree (tmp);
@@ -322,26 +335,52 @@ parseHistory (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
   return;
 }
 
+
+static gint
+readxmlprefs (gchar * xmlsource, gboolean from_file);
+
 /**
- * Top-level function to read the denemotc xml file.
+ * Read a denemo preferences xml file.
  * @param filename - denemorc file name 
  * @param prefs - struct to populate data into
-
  *
  */
+
 static gint
-readxmlprefs (gchar * filename, DenemoPrefs * prefs)
+readxmlprefsFile (gchar * filename) {
+  return readxmlprefs(filename,  TRUE);
+}
+
+/**
+ * Read denemo preferences from an xml string.
+ * @param content - a string containing prefs in xml 
+ *
+ */
+gint
+readxmlprefsString (gchar * content) {
+  gchar *xml = g_strconcat("<?xml version=\"1.0\"?><Denemo><Config>", content, "</Config></Denemo>", NULL);
+  gint ret= readxmlprefs(xml, FALSE);
+  g_free(xml);
+  return ret;
+}
+
+
+
+static gint
+readxmlprefs (gchar * xmlsource,  gboolean from_file)
 {
+  DenemoPrefs * prefs = &Denemo.prefs;
   gint ret = -1;
   xmlDocPtr doc = NULL;
   xmlNodePtr rootElem;
 
-
-  doc = xmlParseFile (filename);
-
+  if(from_file) 
+    doc = xmlParseFile (xmlsource);
+  else
+    doc = xmlReadMemory(xmlsource, strlen(xmlsource), "noname.xml", NULL, 0);
   if (doc == NULL)
     {
-      g_warning ("Could not read XML file %s", filename);
+      g_warning ("Could not read XML %s %s\n", from_file?"File: ":":\n", xmlsource);
       return ret;
     }
 
@@ -424,9 +463,14 @@ writeXMLPrefs (DenemoPrefs * prefs)
   child = xmlNewChild (parent, NULL, (xmlChar *) "Config", NULL);
 
 #define WRITEXMLENTRY(field) \
-  if (prefs->field)\
+  if (prefs->field){\
+    gchar *def = g_strdup("Holds the value of the user's " #field " preference");\
+    gchar *curname = g_strdup_printf("DenemoPref_%s", #field);\
+    define_scheme_variable(curname, prefs->field->str, def);\
+    g_free(curname);\
+    g_free(def);\
     xmlNewChild (child, NULL, (xmlChar *) #field,\
-		 (xmlChar *) prefs->field->str);
+		 (xmlChar *) prefs->field->str);}
 
   WRITEXMLENTRY(lilypath)
   WRITEXMLENTRY(midiplayer)
@@ -444,9 +488,16 @@ writeXMLPrefs (DenemoPrefs * prefs)
   WRITEXMLENTRY(sequencer)
   WRITEXMLENTRY(lilyversion)
  
-#define WRITEINTXMLENTRY(field) \
+#define WRITEINTXMLENTRY(field){ \
+    gchar *def = g_strdup("Holds the value of the user's " #field " preference");\
+    gchar *value = g_strdup_printf("%d", prefs->field);\
+    gchar *curname = g_strdup_printf("DenemoPref_%s", #field);\
+    define_scheme_variable(curname, value, def);\
+    g_free(curname);\
+    g_free(value);\
+    g_free(def);\
   newXMLIntChild (child, (xmlChar *) #field,\
-		  prefs->field);
+		  prefs->field);}
 
   WRITEINTXMLENTRY(autosave)
   WRITEINTXMLENTRY(autosave_timeout)
