@@ -44,7 +44,7 @@ typedef struct lilyversion
 
 #define GPID_NONE (-1)
 static GPid printviewpid = GPID_NONE;
-
+static gint printpreview_errors=-1;
 static GPid printpid = GPID_NONE;
 static gint output=-1;
 static gint errors=-1;
@@ -244,6 +244,8 @@ process_lilypond_errors(gchar *filename){
   gint numbytes = read(errors, bytes, bufsize-1);
   close(errors);
   errors = -1;
+#undef bufsize
+
   if(numbytes==-1) {
     g_free(bytes);
     return;
@@ -259,7 +261,7 @@ process_lilypond_errors(gchar *filename){
 	warningdialog("Spurious line number"), line = 0;
       /* gchar *errmsg = g_strdup_printf("Error at line %d column %d %d", line,column, cnv); */
       /*     warningdialog(errmsg); */
-      infodialog(epoint);/* FIXME PUT OUTPUT IN CONSOLE WINDOW HERE */
+      console_output(epoint);
       if(gui->textbuffer) {
 	set_lily_error(line+1, column, gui);
       } 
@@ -275,7 +277,7 @@ process_lilypond_errors(gchar *filename){
   if (lily_err != NULL)
     {
       if(*bytes)
-	infodialog(bytes);
+	console_output(bytes);
       warningdialog("Could not execute lilypond - check Edit->preferences->externals->lilypond setting\nand lilypond installation");
       g_warning ("%s", lily_err->message);
       if(lily_err) g_error_free (lily_err);
@@ -297,7 +299,7 @@ open_viewer(GPid pid, gint status, gchar *filename, gboolean is_png){
   process_lilypond_errors(filename); 
 
   if (is_png)
-	printfile = g_strconcat (filename, ".png", NULL);
+	printfile = g_strconcat (filename, "_.png", NULL);
   else
   	printfile = g_strconcat (filename, ".pdf", NULL);
   
@@ -363,46 +365,55 @@ open_pdfviewer(GPid pid, gint status, gchar *filename){
 void
 run_lilypond(gchar *filename, DenemoGUI *gui){
 
-  gchar **arguments;
   gchar *lilyfile = g_strconcat (filename, ".ly", NULL);
   gchar *resolution = g_strdup_printf("-dresolution=%d",(int) Denemo.prefs.resolution);
-
+  gchar *printfile = g_strconcat (filename, "_", NULL);
   /* Check Lilypond Version */
   //if (get_lily_version("2.12") != SAME)
     convert_ly(lilyfile);
-#if GLIB_MINOR_VERSION >= 14
-   gchar *backend;
-  if (get_lily_version("2.12") >= 1)
-    backend = "-dbackend=eps";
-  else
-    backend = "-b eps";
 
-  gchar *png[] = {
+#if GLIB_MINOR_VERSION >= 14
+  gchar **arguments; 
+  gchar *png_arguments1[] = {
     Denemo.prefs.lilypath->str,
     "--png",
-    backend,
+    "-dbackend=eps",
     resolution,
     "-o",
-    filename,
+    printfile,
     lilyfile,
     NULL
   };
-#else
-  gchar *png[] = {
+  gchar *png_arguments2[] = {
     Denemo.prefs.lilypath->str,
     "--png",
     "-b",
     "eps",
     resolution,
     "-o",
-    filename,
+    printfile,
+    lilyfile,
+    NULL
+  };
+  
+  if (get_lily_version("2.12") >= 1)
+     arguments = png_arguments1;
+  else
+     arguments = png_arguments2;
+#else
+  gchar *png_arguments[] = {
+    Denemo.prefs.lilypath->str,
+    "--png",
+    "-b",
+    "eps",
+    resolution,
+    "-o",
+    printfile,
     lilyfile,
     NULL
   };
 #endif
 
-
-
   gchar *pdf[] = {
     Denemo.prefs.lilypath->str,
     "--pdf",
@@ -411,12 +422,9 @@ run_lilypond(gchar *filename, DenemoGUI *gui){
     lilyfile,
     NULL
   };
-  if (gui->lilycontrol.excerpt){	  
-	  arguments = png;
-  }
-  else {
+  if (!gui->lilycontrol.excerpt)	  
 	  arguments = pdf;
-  }
+  
   g_spawn_async_with_pipes (locatedotdenemo (),		/* dir */
 		arguments, NULL,	/* env */
 		G_SPAWN_SEARCH_PATH  | G_SPAWN_DO_NOT_REAP_CHILD, NULL,	/* child setup func */
@@ -426,6 +434,10 @@ run_lilypond(gchar *filename, DenemoGUI *gui){
 		NULL,		/* stdout */
 		&errors,		/* stderr */
 		&lily_err);
+  if (gui->lilycontrol.excerpt == TRUE)
+    g_child_watch_add (printpid, (GChildWatchFunc)open_pngviewer  /*  GChildWatchFunc function */, filename);
+  else
+    g_child_watch_add (printpid, (GChildWatchFunc)open_pdfviewer  /*  GChildWatchFunc function */, filename);
 }
 
 /* Run the LilyPond interpreter on the file (filename).ly
@@ -449,7 +461,7 @@ run_lilypond_and_viewer(gchar *filename, DenemoGUI *gui) {
   /* remove old output files to avoid confusion */
   gchar *printfile;
   if (gui->lilycontrol.excerpt == TRUE)
-    printfile = g_strconcat (filename, ".png", NULL);
+    printfile = g_strconcat (filename, "_.png", NULL);
   else
     printfile = g_strconcat (filename, ".pdf", NULL);
   FILE *fp = fopen(printfile, "w");
@@ -458,10 +470,7 @@ run_lilypond_and_viewer(gchar *filename, DenemoGUI *gui) {
   g_free(printfile);
   run_lilypond(filename, gui);
   //  g_print("print pid is %d\n", printpid);
-  if (gui->lilycontrol.excerpt == TRUE)
-    g_child_watch_add (printpid, (GChildWatchFunc)open_pngviewer  /*  GChildWatchFunc function */, filename);
-  else
-    g_child_watch_add (printpid, (GChildWatchFunc)open_pdfviewer  /*  GChildWatchFunc function */, filename);
+
 }
 
 /* returns the base name (~/.denemo/denemoprint usually) used as a base
@@ -596,12 +605,25 @@ void
 printpreview_cb (GtkAction *action, gpointer param) {
   DenemoGUI *gui = Denemo.gui;
   gui->lilycontrol.excerpt = FALSE;
-  if(gui->si->markstaffnum)
-    if(confirm("A range of music is selected","Print whole file?")){
-      gui->si->markstaffnum=0;
-    }
-  print(gui, FALSE, TRUE);
+  gui->si->markstaffnum=0;//FIXME save and restore selection?    
+  if((gui->movements && g_list_length(gui->movements)>1) && 
+     (confirm("This piece has several movements", "Print all of them?")))
+    print(gui, FALSE, TRUE);
+  else
+    print(gui, FALSE, FALSE);
 }
+
+void
+printselection_cb (GtkAction *action, gpointer param) {
+  DenemoGUI *gui = Denemo.gui;
+  gui->lilycontrol.excerpt = FALSE;
+  if(gui->si->markstaffnum)
+    print(gui, FALSE, FALSE);
+  else
+    warningdialog(_("No selection to print"));
+}
+
+
 void
 printexcerptpreview_cb (GtkAction *action, gpointer param) {
   DenemoGUI *gui = Denemo.gui;
@@ -795,7 +817,7 @@ static void draw_print(DenemoGUI *gui) {
 			gcs_graygc(), TRUE, markx, marky, w, h);
 
       gdk_draw_pixbuf(gui->printarea->window, NULL, GDK_PIXBUF(gui->pixbuf),
-		  markx, marky, curx, cury,/* x, y in pixbuf, x,y in window */
+		  markx+x, marky+y, curx, cury,/* x, y in pixbuf, x,y in window */
 		w,  h, GDK_RGB_DITHER_NONE,0,0);
 
     }
@@ -809,7 +831,7 @@ static void draw_print(DenemoGUI *gui) {
       gdk_draw_rectangle (Denemo.gui->printarea->window,
 			gcs_graygc(), TRUE, markx-pad/2, marky-pad/2, w+pad, h+pad);
       gdk_draw_pixbuf(gui->printarea->window, NULL, GDK_PIXBUF(gui->pixbuf),
-		      markx, marky, markx, marky,/* x, y in pixbuf, x,y in window FIXME after scrolling */
+		      markx+x, marky+y, markx, marky,/* x, y in pixbuf, x,y in window */
 		w,  h, GDK_RGB_DITHER_NONE,0,0);
 
     }
@@ -826,6 +848,21 @@ static void normal_cursor(void) {
  gdk_window_set_cursor(Denemo.gui->printarea->window, arrowcursor);
 }
 
+static void
+process_printpreview_errors(void){
+  DenemoGUI *gui = Denemo.gui;
+  if (printpreview_errors == -1)
+    return;
+#define bufsize (1000)
+  gchar *bytes = g_malloc0(bufsize);
+  gint numbytes = read(printpreview_errors, bytes, bufsize-1);
+  close(printpreview_errors);
+  printpreview_errors = -1;
+#undef bufsize
+  if(*bytes)
+    console_output(bytes);
+  g_free(bytes);
+}
 static void
 printview_finished(void) {
   DenemoGUI *gui = Denemo.gui;
@@ -833,7 +870,7 @@ printview_finished(void) {
   printviewpid = GPID_NONE;
   GError *error = NULL;
   normal_cursor();
-
+  process_printpreview_errors();
   gchar *filename = get_printfile_pathbasename();
   gchar *path = g_strconcat (filename, "_.png", NULL);
   if(gui->pixbuf)
@@ -932,11 +969,14 @@ void refresh_print_view (void) {
   busy_cursor();
   changecount = Denemo.gui->changecount;// keep track so we know it update is needed
 
-  g_spawn_async (locatedotdenemo (),		/* dir */
+  g_spawn_async_with_pipes (locatedotdenemo (),		/* dir */
 		 arguments, NULL,	/* env */
 		 G_SPAWN_SEARCH_PATH | G_SPAWN_DO_NOT_REAP_CHILD, NULL,	/* child setup func */
 		 NULL,		/* user data */
 		 &printviewpid,
+		 NULL,
+		 NULL,		/* stdout */
+	         &printpreview_errors,		/* stderr */
 		 &error);
   g_free(lilyfile);
   g_child_watch_add (printviewpid, (GChildWatchFunc)printview_finished  /*  GChildWatchFunc function */, NULL);
@@ -981,7 +1021,7 @@ printarea_configure_event (GtkWidget * widget, GdkEventConfigure * event)
 {
   DenemoGUI *gui = Denemo.gui;
   if(gui->pixbuf==NULL)
-    return;
+    return FALSE;
   gint width, height;
   gdk_drawable_get_size (gui->printarea->window, &width, &height);
   GtkAdjustment * vadjust = gtk_range_get_adjustment(GTK_RANGE(gui->printvscrollbar));
@@ -996,6 +1036,7 @@ printarea_configure_event (GtkWidget * widget, GdkEventConfigure * event)
 
   gtk_adjustment_changed(vadjust);
   gtk_adjustment_changed(hadjust);
+  return TRUE;
 }
 
 static gint adjust_x=0;
@@ -1025,8 +1066,9 @@ printarea_expose_event (GtkWidget * widget, GdkEventExpose * event)
 {
   DenemoGUI *gui = Denemo.gui;
   if(gui->pixbuf==NULL)
-    return;
+    return TRUE;
   draw_print(gui);
+  return TRUE;
 }
 
 
@@ -1097,7 +1139,7 @@ printarea_button_press (GtkWidget * widget, GdkEventButton * event)
       g_free(msg);
     }
     offsetting = FALSE;
-    return;
+    return TRUE;
   }
   /*( creating a padding value? */
   if(padding) {
@@ -1112,7 +1154,7 @@ printarea_button_press (GtkWidget * widget, GdkEventButton * event)
       g_free(msg);
     }
     padding = FALSE;
-    return;
+    return TRUE;
   }
 
 
