@@ -20,7 +20,7 @@
 #include "prefops.h"
 /*For save selection function*/
 #include "utils.h"
-
+#define DEBUG 1
 /**
  * The copy buffer is a GList of objnode *s -- at first, I was going
  * to use staffnode *s, measurenode *s, and then objnode *s, but I
@@ -151,12 +151,8 @@ copytobuffer (DenemoScore * si)
 	      theobjs = g_list_append (theobjs, clonedobject);
 	    }			/* End object loop */
 	  g_debug ("cloned objects on staff \n");
-	  if (staffsinbuffer > 1)
-	    {
-	      theobjs = g_list_append (theobjs, newstaffbreakobject ());
-	      g_debug ("Inserting Staffbreak object in copybuffer");
-	    }
-	  else if (j < si->lastmeasuremarked || k < si->lastobjmarked)
+	  
+	  if (j < si->lastmeasuremarked || k < si->lastobjmarked)
 	    {
 	      g_debug ("Insert measurebreak obj in copybuffer");
 	      /* That is, there's another measure, the cursor is in appending
@@ -167,9 +163,13 @@ copytobuffer (DenemoScore * si)
 		measurebreaksinbuffer++;
 	    }
 	  k = 0;		/* Set it for next run through object loop */
-
+	  
 	}			/* End measure loop */
-
+      if (staffsinbuffer > 1)
+	{
+	  theobjs = g_list_append (theobjs, newstaffbreakobject ());
+	  g_debug ("Inserting Staffbreak object in copybuffer");
+	}
       copybuffer = g_list_append (copybuffer, theobjs);
     }				/* End staff loop */
 }
@@ -187,15 +187,16 @@ cuttobuffer (DenemoScore * si)
   staffnode *curstaff;
   measurenode *curmeasure;
   objnode *tempobj;
-  gint i, jcounter, max;
-  if (!si->firstmeasuremarked)
+  gint i, jcounter, //jcounter is marking the position of the measure currently being cleared I think
+    max;
+  if (!si->markstaffnum)
     return;
   copytobuffer (si);
-
+  gint staffs_removed_measures = 0;// a count of removed measures in the case where multiple staffs are involved
   if (staffsinbuffer == 1)
     {
       /* Just a single staff is a special case, again.  */
-      jcounter = si->firstmeasuremarked;
+      jcounter = si->firstmeasuremarked; //currently clearing stuff from the firstmeasuremarked
       curmeasure = g_list_nth (firstmeasurenode (si->currentstaff), jcounter - 1);
 
       /* Clear the relevant part of the first measure selected */
@@ -212,17 +213,18 @@ cuttobuffer (DenemoScore * si)
 	  freeobject ((DenemoObject *) tempobj->data);
 	  g_list_free_1 (tempobj);
 	}
-      jcounter++;
+      jcounter++; //move on to the second measure being cleared
       curmeasure = curmeasure->next;
 
       if (!si->thescore->next)
 	{
-	  /* That is, the score has only this one staff */
+	  /* That is, the score has only this one staff
+	   remove the (whole) measures between the first and last - which may be partial.*/
 	  if (measurebreaksinbuffer - 1 > 0)
 	    {
 	      curmeasure =
 		removemeasures (si, jcounter - 1, measurebreaksinbuffer - 1, TRUE);
-	      jcounter += measurebreaksinbuffer - 1;
+	      jcounter += measurebreaksinbuffer - 1;// increased by the number of measures *between* first and last marked
 	    }
 	}
       else
@@ -233,7 +235,7 @@ cuttobuffer (DenemoScore * si)
 	    curmeasure->data = NULL;
 	  }
       /* Now clear the relevant part of the last measure selected */
-      if (jcounter <= si->lastmeasuremarked)
+      if (curmeasure && (jcounter <= si->lastmeasuremarked))
 	{
 	  for (i = 0; curmeasure->data && i <= si->lastobjmarked; i++)
 	    {
@@ -245,8 +247,16 @@ cuttobuffer (DenemoScore * si)
 	    }
 	  /* And delete it, if the measure's been cleared and there's only
 	     one staff.  */
+#if 0
 	  if (!curmeasure->data && !si->thescore->next)
-	    removemeasures (si, jcounter - 1, 1, TRUE);
+	    removemeasures (si, jcounter - 1, 1, TRUE);//WRONG the other measures have been removed, so jcounter no longer indexes anything in the staff!
+#else
+	  if (!curmeasure->data && !si->thescore->next)
+	    removemeasures (si, g_list_position(firstmeasurenode(si->currentstaff), curmeasure), 1, TRUE);
+#endif
+
+
+
 	}
       showwhichaccidentalswholestaff ((DenemoStaff *) si->currentstaff->data);
       beamsandstemdirswholestaff ((DenemoStaff *) si->currentstaff->data);
@@ -257,10 +267,20 @@ cuttobuffer (DenemoScore * si)
 	{
 	  /* Every staff was part of the selection */
 	  if (measurebreaksinbuffer > 0)
-	    removemeasures (si, si->firstmeasuremarked - 1,
+	    {
+	      
+	      removemeasures (si, si->firstmeasuremarked - 1,
 			    measurebreaksinbuffer, TRUE);
+	      staffs_removed_measures = measurebreaksinbuffer;
+	    }
 	  for (curstaff = si->thescore; curstaff; curstaff = curstaff->next)
 	    {
+	      if(measurebreaksinbuffer==0)
+		{
+		  curmeasure = g_list_nth (firstmeasurenode (curstaff),  si->firstmeasuremarked-1);
+		  freeobjlist (curmeasure->data, NULL);
+		  curmeasure->data = NULL;
+		}
 	      showwhichaccidentalswholestaff ((DenemoStaff *) curstaff->data);
 	      beamsandstemdirswholestaff ((DenemoStaff *) curstaff->data);
 	    }
@@ -290,15 +310,28 @@ cuttobuffer (DenemoScore * si)
 	    }
 	}
     }
-  si->markstaffnum = 0;
+  si->firststaffmarked = si->markstaffnum = 0;//only the latter is needed, but there was some confusion at one time...
   /* And set some currents. This would probably be better to split off
    * into a more-generalized version of setcurrents or something;
    * what's here is more-or-less copied from dnm_deleteobject in
    * commandfuncs */
 
-  si->currentmeasurenum = si->firstmeasuremarked;
+  si->currentmeasurenum = si->firstmeasuremarked - (staffs_removed_measures?1:0);
+
+  if(si->currentmeasurenum<1) {
+    si->currentmeasurenum = 1;
+  }
+
+
   si->currentmeasure = g_list_nth (firstmeasurenode (si->currentstaff),
 				   si->currentmeasurenum - 1);
+#if 0
+  if(si->currentmeasure==NULL)
+    si->currentmeasure = g_list_last (firstmeasurenode (si->currentstaff));
+#endif
+
+
+
   si->cursor_x = si->firstobjmarked;
   if (si->cursor_x <
       (gint) (g_list_length ((objnode *) si->currentmeasure->data)))
@@ -329,27 +362,47 @@ cuttobuffer (DenemoScore * si)
  * pastefrombuffer
  * Pastes the current buffer to the score
  *
- * @param gui the DenemoGUI to be used.
+
  *
  * The updates that are done towards the bottom of this function -
  * beamsandstemdirswholestaff, find_xes_in_all_measures, etc. - are
  * too much gruntwork and are inefficient in terms of everything
  * but additional lines-of-code required for implementation. 
+ * return FALSE if no pasting was done.
  */
 
-static void
-pastefrombuffer (DenemoGUI * gui)
+static gboolean
+pastefrombuffer (void)
 {
+  DenemoGUI *gui = Denemo.gui;
   DenemoScore *si = gui->si;
   staffnode *curstaff;
   measurenode *curmeasure;
   GList *curbuffernode = copybuffer;
   objnode *curbufferobj;
-  gint insertat, initialinsertat;
+  gint initialinsertat;
   DenemoObject *clonedobject;
-
+  gint staffs_used = 0;//number of staffs we have pasted into after the first
   gint i, j;
-  gint measurestoadd = 0;
+  gint measuretoaddat = si->currentmeasurenum;
+  if((staffsinbuffer>1) || (measurebreaksinbuffer>0)) {
+    /* g_print("si->appending=%d si->cursoroffend=%d curobjnot1st=%d\n", si->cursor_appending, si->cursoroffend, 
+       (si->currentobject!=si->currentmeasure->data));*/
+
+    if((!si->cursor_appending) && (si->currentobject!=si->currentmeasure->data))
+      return FALSE;
+    if(si->currentobject) {
+      //g_print("Adding %d measures at %d\n", measurebreaksinbuffer+(staffsinbuffer==1), si->currentmeasurenum);
+      if(si->cursor_appending) {
+	addmeasures (si, si->currentmeasurenum, measurebreaksinbuffer+(staffsinbuffer==1), (staffsinbuffer>1));
+	measureright(NULL);measuretoaddat++;//Better check measureright worked
+      } else {
+	addmeasures (si, si->currentmeasurenum-1, measurebreaksinbuffer+(staffsinbuffer==1), (staffsinbuffer>1));
+      }
+      setcurrents (gui->si);
+    }
+    //currentobject is NULL, currentmeasure is first of added measures
+  }
 
   /* All right. Any necessary measures have been inserted - now paste away */
 
@@ -361,46 +414,41 @@ pastefrombuffer (DenemoGUI * gui)
   g_debug ("Insert At position %d\n", initialinsertat);
 
   for (curstaff = si->currentstaff; curstaff && curbuffernode;
-       curstaff = curstaff->next, curbuffernode = curbuffernode->next)
+       curstaff? curstaff = si->currentstaff:0, curbuffernode = curbuffernode->next)
     {
 
       g_debug ("Current staff %x, Current Staff Next %x,"
 	       " CurBuf %x, CurBuf Next %x\n",
 	       curstaff, curstaff->next, curbuffernode, curbuffernode->next);
 
+      //gint prevailing_clef = find_prevailing_clef(si);
+
       curmeasure = g_list_nth (firstmeasurenode (curstaff),
 			       si->currentmeasurenum - 1);
-      insertat = initialinsertat;
+
+      
       for (curbufferobj = (objnode *) curbuffernode->data;
 	   curbufferobj && curmeasure; curbufferobj = curbufferobj->next)
 	{
-	  if (((DenemoObject *) curbufferobj->data)->type == STAFFBREAK)
+	  DenemoObject *curobj = (DenemoObject *) curbufferobj->data;
+	  if (curobj->type == STAFFBREAK)
 	    {
-	      break;
+
+	     break;
 	    }
-	  else if (((DenemoObject *) curbufferobj->data)->type ==
+	  else if (curobj->type ==
 		   MEASUREBREAK)
 	    {
 	      /*Do nothing as we will not insert a new barline at 
 		this point. It is done automatically */
 	      g_debug("Have measurebreak object\n");
-	      /*if (!si->currentmeasure->next && si->cursor_appending)
-		/* Add a measure and make it currentmeasure *
-		if (staffsinbuffer == 1)
-		  si->currentmeasure =
-		    dnm_addmeasures (si, si->currentmeasurenum, 1, FALSE);
-		else
-		  si->currentmeasure =
-		    dnm_addmeasures (si, si->currentmeasurenum, 1, TRUE);
-	      else if(si->cursor_appending)
-		si->currentmeasure = si->currentmeasure->next;*/
-	      /*curmeasure = curmeasure->next;*/
+	    
 	    }
 	  else
 	    {
 	      g_debug("Paste: Cursor Position %d\n", si->cursor_x);
 	      clonedobject =
-		dnm_clone_object ((DenemoObject *) curbufferobj->data);
+		dnm_clone_object (curobj);
 	      
 	      clonedobject->starttick = (si->currentobject?
 					 ((DenemoObject *)si->currentobject->data)->starttickofnextnote: 0);//guess
@@ -409,23 +457,33 @@ pastefrombuffer (DenemoGUI * gui)
 		       si->cursoroffend, clonedobject->starttick);
 	      insertion_point (si);
 	      object_insert(gui, clonedobject);
-	      /*	      curmeasure->data =
-	      g_list_insert ((objnode *) curmeasure->data, clonedobject,
-	      insertat);*/
-	      beamandstemdirhelper(si);
-	      
+
 	      si->cursoroffend = (si->currentobject?
 		((DenemoObject *)si->currentobject->data)->starttickofnextnote
 				  >= (WHOLE_NUMTICKS * si->cursortime1 / si->cursortime2): 0);   // guess  
 
-	      insertat++;
-	    }
+
+	    } //not a staff break
 	}			/* End bufferobj loop */
+      fixnoteheights(curstaff->data);
       showwhichaccidentalswholestaff ((DenemoStaff *) curstaff->data);
       beamsandstemdirswholestaff ((DenemoStaff *) curstaff->data);
-    }				/* End staff loop */
-
-
+      si->currentmeasurenum =  measuretoaddat;
+      curstaff = si->currentstaff->next;
+      if(staffsinbuffer>1) {
+	DenemoScriptParam param; 
+	if(!staffdown(&param))
+	  break;//FIXME wrap this function up to be called from C
+	staffs_used++;
+      }
+      setcurrents (gui->si);
+    } /* End staff loop */
+  // g_print("check %d against %d\n", staffsinbuffer, staffs_used);
+  while(staffs_used--)
+    {
+      DenemoScriptParam param; 
+      staffup(&param);
+    }
   si->currentmeasure = g_list_nth (firstmeasurenode (si->currentstaff),
 				   si->currentmeasurenum - 1);
   si->currentobject = g_list_nth ((objnode *) si->currentmeasure->data,
@@ -435,7 +493,10 @@ pastefrombuffer (DenemoGUI * gui)
     si->cursor_appending = TRUE;
   else
     si->cursor_appending = FALSE;
+  find_xes_in_all_measures (si);
+
   g_debug ("End of Paste Cursor X: %d\n", si->cursor_x);
+  return TRUE;
 }
 
 
@@ -448,7 +509,7 @@ DenemoObject *get_mark_object(void){
   DenemoStaff *firststaff =  (DenemoStaff *) curstaff->data;
   measurenode *firstmeasure = g_list_nth (firststaff->measures,  si->firstmeasuremarked - 1);
   objnode *firstobj = g_list_nth (firstmeasure->data, si->firstobjmarked);
-  g_print("First %d\n",  si->firstobjmarked);
+  //g_print("First %d\n",  si->firstobjmarked);
   return firstobj? ((DenemoObject *)firstobj->data):NULL;
 }
 DenemoObject *get_point_object(void){
@@ -572,7 +633,7 @@ goto_nearestnote (GtkAction *action, gpointer param) {
  * 
  */
 void
-goto_mark (GtkAction *action, gpointer param)
+goto_mark (GtkAction *action, DenemoScriptParam *param)
 {
   DenemoScore *si = Denemo.gui->si;
   if(!action)
@@ -599,7 +660,7 @@ goto_mark (GtkAction *action, gpointer param)
  * @param gui pointer to the DenemoGUI structure
  */
 void
-copywrapper (GtkAction *action, gpointer param)
+copywrapper (GtkAction *action, DenemoScriptParam *param)
 {
   DenemoGUI *gui = Denemo.gui;
   copytobuffer (gui->si);
@@ -613,10 +674,11 @@ copywrapper (GtkAction *action, gpointer param)
  * @param gui pointer to the DenemoGUI structure 
  */
 void
-cutwrapper (GtkAction *action, gpointer param)
+cutwrapper (GtkAction *action, DenemoScriptParam *param)
 {
   DenemoGUI *gui = Denemo.gui;
   cuttobuffer (gui->si);
+  //check that measurewidths is long enough after cutting empty measures
   displayhelper (gui);
 }
 
@@ -628,12 +690,22 @@ cutwrapper (GtkAction *action, gpointer param)
  * @param action pointer to the GtkAction event
  */
 void
-pastewrapper (GtkAction *action, gpointer param)
-{
+pastewrapper (GtkAction *action, DenemoScriptParam *param)
+{  
   DenemoGUI *gui = Denemo.gui;
-  pastefrombuffer (gui);
+  gboolean pasted = pastefrombuffer ();
+  if(pasted) {
   score_status(gui, TRUE);
   displayhelper (gui);
+  } else {
+    if(!action && param)
+      param->status = FALSE;
+    else
+      if(copybuffer)
+	warningdialog("Cannot paste multiple measures into middle of a measure");
+      else
+	warningdialog("Nothing to paste");
+  }
 }
 
 
@@ -645,7 +717,7 @@ pastewrapper (GtkAction *action, gpointer param)
  * @param gui pointer to the DenemoGUI structure
  */
 void
-saveselwrapper (GtkAction *action, gpointer param)
+saveselwrapper (GtkAction *action, DenemoScriptParam *param)
 {
   DenemoGUI *gui = Denemo.gui;
   saveselection (gui->si);
@@ -690,7 +762,7 @@ mark_boundaries_helper (DenemoScore * si, gint mark_staff,
 	  si->firstmeasuremarked = MIN (mark_measure, point_measure);
 	  si->lastmeasuremarked = MAX (mark_measure, point_measure);
 	  if (type == NORMAL_SELECT
-	      /*  && si->firststaffmarked == si->laststaffmarked */)
+	        && si->firststaffmarked == si->laststaffmarked )
 	    {
 	      if (mark_measure < point_measure)
 		{
@@ -817,7 +889,7 @@ undo (DenemoGUI * gui)
 
 	  g_debug ("UNDO Delete Object %d\n",
 		   ((DenemoObject *) undo->object)->type);
-	  g_debug ("Cursur position before UNDO %d\n", gui->si->cursor_x);
+	  g_debug ("Cursor position before UNDO %d\n", gui->si->cursor_x);
 	  g_debug ("Cursor Position %d\n", gui->si->cursor_x);
 
 	  setcurrents (gui->si);
