@@ -32,6 +32,16 @@ void popup_menu(gchar *name) {
  gtk_menu_popup (GTK_MENU(menu), NULL, NULL, NULL, NULL,0, gtk_get_current_event_time()); 
 }
 
+/**
+ * outputs a warning and sounds bell
+ * @return none
+ */
+void
+warningmessage (gchar * msg)
+{
+  gdk_beep();
+  g_message("%s", msg);
+}
 
 /**
  * Pops up a warning dialog and blocks until it is dismissed
@@ -1050,3 +1060,14 @@ void console_output(gchar *text) {
   gtk_text_buffer_get_end_iter (buffer,  &enditer);
   gtk_text_buffer_insert(buffer, &enditer, text, -1);
 }
+
+/* returns an override flag ORd from all those in the list of directives */
+gint get_override(GList *g) {
+  gint ret = 0;
+  for(;g;g=g->next) {
+    DenemoDirective *d = g->data;
+    ret |= d->override;
+  }
+  return ret;
+}
+
