@@ -44,7 +44,7 @@
 #define EXTRA_ACCELS "extra.accels"
 
 
-void newtab (GtkAction *action, gpointer param);
+void newview (GtkAction *action, gpointer param);
 void free_gui(DenemoGUI *gui);/* frees all movement data from gui, leaving gui interface intact */
 void addhistorymenuitem(gchar *filename);
 
@@ -64,12 +64,11 @@ void	  highlight_rest(DenemoGUI *gui, gint dur);
 gboolean loadGraphicItem(gchar *name, GdkBitmap **xbm, gint *width, gint *height );
 
 void denemo_scheme_init(gchar *initscheme);
-gchar *getSchemeText(void); 
-void deleteSchemeText(void);
-void appendSchemeText(gchar *text);
-void executeScript(void);
+
+void activate_action(gchar *path);
+
 GError *execute_script_file(gchar *filename);
-gint getNumCharsSchemeText(void);
+
 gboolean
 activate_script (GtkAction *action, gpointer param);
 void 
@@ -86,4 +85,9 @@ void
 upload_edit_script(gchar *tag, gchar *script);
 void 
 execute_init_scripts(gchar *menupath);
+
+void
+load_local_scheme_init(void);
+
+
 #endif
